# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nifgen.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nidevice_pb2 as nidevice__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cnifgen.proto\x12\x0bnifgen_grpc\x1a\x0enidevice.proto\x1a\rsession.proto\"\xb1\x01\n\x0bInitRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"~\n\x0cInitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xd3\x01\n\x16InitWithOptionsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x89\x01\n\x17InitWithOptionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xde\x01\n\x1dInitializeWithChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x03 \x01(\t\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x90\x01\n\x1eInitializeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\"7\n\x11\x45rrorQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"O\n\x12\x45rrorQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x15\n\rerror_message\x18\x03 \x01(\t\"M\n\x13\x45rrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"Q\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x19\n\x11\x65rror_description\x18\x03 \x01(\t\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"M\n\x13\x45rrorHandlerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorHandlerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\"@\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x16\n\x0e\x63hannel_string\x18\x02 \x01(\t\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rCommitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\" \n\x0e\x43ommitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"=\n\x17GetHardwareStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"h\n\x18GetHardwareStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x1a.nifgen_grpc.HardwareState\x12\x11\n\tstate_raw\x18\x03 \x01(\x11\"L\n\x14WaitUntilDoneRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08max_time\x18\x02 \x01(\x11\"\'\n\x15WaitUntilDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rIsDoneRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\".\n\x0eIsDoneResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04\x64one\x18\x02 \x01(\x08\"8\n\x12ResetDeviceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"%\n\x13ResetDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n\x1d\x43onfigureOperationModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0eoperation_mode\x18\x03 \x01(\x11\"0\n\x1e\x43onfigureOperationModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9f\x01\n\x1a\x43onfigureOutputModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12.\n\x0boutput_mode\x18\x02 \x01(\x0e\x32\x17.nifgen_grpc.OutputModeH\x00\x12\x19\n\x0foutput_mode_raw\x18\x03 \x01(\x11H\x00\x42\x12\n\x10output_mode_enum\"-\n\x1b\x43onfigureOutputModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x01\n\x1e\x43onfigureReferenceClockRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16reference_clock_source\x18\x02 \x01(\t\x12!\n\x19reference_clock_frequency\x18\x03 \x01(\x01\"1\n\x1f\x43onfigureReferenceClockResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"n\n\x1f\x43onfigureOutputImpedanceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\timpedance\x18\x03 \x01(\x01\"2\n ConfigureOutputImpedanceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x1d\x43onfigureOutputEnabledRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"0\n\x1e\x43onfigureOutputEnabledResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"P\n\x18\x43onfigureChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannels\x18\x02 \x01(\t\"+\n\x19\x43onfigureChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"?\n\x19InitiateGenerationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\",\n\x1aInitiateGenerationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"<\n\x16\x41\x62ortGenerationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\")\n\x17\x41\x62ortGenerationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xfe\x01\n ConfigureStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12)\n\x08waveform\x18\x03 \x01(\x0e\x32\x15.nifgen_grpc.WaveformH\x00\x12\x16\n\x0cwaveform_raw\x18\x04 \x01(\x11H\x00\x12\x11\n\tamplitude\x18\x05 \x01(\x01\x12\x11\n\tdc_offset\x18\x06 \x01(\x01\x12\x11\n\tfrequency\x18\x07 \x01(\x01\x12\x13\n\x0bstart_phase\x18\x08 \x01(\x01\x42\x0f\n\rwaveform_enum\"3\n!ConfigureStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n!DefineUserStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x01\"4\n\"DefineUserStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\\\n ClearUserStandardWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"3\n!ClearUserStandardWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n\x19\x43onfigureFrequencyRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfrequency\x18\x03 \x01(\x01\",\n\x1a\x43onfigureFrequencyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n\x19\x43onfigureAmplitudeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tamplitude\x18\x03 \x01(\x01\",\n\x1a\x43onfigureAmplitudeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eQueryArbWfmCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xae\x01\n\x1fQueryArbWfmCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12#\n\x1bmaximum_number_of_waveforms\x18\x02 \x01(\x11\x12\x18\n\x10waveform_quantum\x18\x03 \x01(\x11\x12\x1d\n\x15minimum_waveform_size\x18\x04 \x01(\x11\x12\x1d\n\x15maximum_waveform_size\x18\x05 \x01(\x11\"q\n\x18\x43reateWaveformF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x01\"D\n\x19\x43reateWaveformF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"q\n\x18\x43reateWaveformI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1b\n\x13waveform_data_array\x18\x03 \x03(\x11\"D\n\x19\x43reateWaveformI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\x98\x01\n\x1f\x43reateWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12;\n\x13waveform_data_array\x18\x03 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\"K\n CreateWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xca\x01\n CreateWaveformFromFileI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12,\n\nbyte_order\x18\x04 \x01(\x0e\x32\x16.nifgen_grpc.ByteOrderH\x00\x12\x18\n\x0e\x62yte_order_raw\x18\x05 \x01(\x11H\x00\x42\x11\n\x0f\x62yte_order_enum\"L\n!CreateWaveformFromFileI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xca\x01\n CreateWaveformFromFileF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12,\n\nbyte_order\x18\x04 \x01(\x0e\x32\x16.nifgen_grpc.ByteOrderH\x00\x12\x18\n\x0e\x62yte_order_raw\x18\x05 \x01(\x11H\x00\x42\x11\n\x0f\x62yte_order_enum\"L\n!CreateWaveformFromFileF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"U\n\x1a\x43onfigureSampleRateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"-\n\x1b\x43onfigureSampleRateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x01\n\x1b\x43onfigureArbWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04gain\x18\x04 \x01(\x01\x12\x0e\n\x06offset\x18\x05 \x01(\x01\".\n\x1c\x43onfigureArbWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x17\x43learArbWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\x0fwaveform_handle\x18\x02 \x01(\x0e\x32\x1b.nifgen_grpc.WaveformHandleH\x00\x12\x1d\n\x13waveform_handle_raw\x18\x03 \x01(\x11H\x00\x42\x16\n\x14waveform_handle_enum\"*\n\x18\x43learArbWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x86\x01\n\x1c\x41llocateNamedWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x15\n\rwaveform_size\x18\x04 \x01(\x11\"/\n\x1d\x41llocateNamedWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xea\x01\n(SetNamedWaveformNextWritePositionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12.\n\x0brelative_to\x18\x04 \x01(\x0e\x32\x17.nifgen_grpc.RelativeToH\x00\x12\x19\n\x0frelative_to_raw\x18\x05 \x01(\x11H\x00\x12\x0e\n\x06offset\x18\x06 \x01(\x11\x42\x12\n\x10relative_to_enum\";\n)SetNamedWaveformNextWritePositionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"}\n\x1cWriteNamedWaveformF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x01\"/\n\x1dWriteNamedWaveformF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"}\n\x1cWriteNamedWaveformI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x11\"/\n\x1dWriteNamedWaveformI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa4\x01\n#WriteNamedWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12,\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\"6\n$WriteNamedWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa1\x01\n#WriteNamedWaveformComplexI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\x12)\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1b.nidevice_grpc.NIComplexI16\"6\n$WriteNamedWaveformComplexI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"m\n\x1a\x44\x65leteNamedWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_name\x18\x03 \x01(\t\"-\n\x1b\x44\x65leteNamedWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eQueryArbSeqCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xb4\x01\n\x1fQueryArbSeqCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12#\n\x1bmaximum_number_of_sequences\x18\x02 \x01(\x11\x12\x1f\n\x17minimum_sequence_length\x18\x03 \x01(\x11\x12\x1f\n\x17maximum_sequence_length\x18\x04 \x01(\x11\x12\x1a\n\x12maximum_loop_count\x18\x05 \x01(\x11\"y\n\x18\x43reateArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16waveform_handles_array\x18\x02 \x03(\x11\x12\x19\n\x11loop_counts_array\x18\x03 \x03(\x11\"D\n\x19\x43reateArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fsequence_handle\x18\x02 \x01(\x11\"\xbd\x01\n CreateAdvancedArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1e\n\x16waveform_handles_array\x18\x02 \x03(\x11\x12\x19\n\x11loop_counts_array\x18\x03 \x03(\x11\x12\x1b\n\x13sample_counts_array\x18\x04 \x03(\x11\x12\x1d\n\x15marker_location_array\x18\x05 \x03(\x11\"k\n!CreateAdvancedArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1d\n\x15\x63oerced_markers_array\x18\x02 \x03(\x11\x12\x17\n\x0fsequence_handle\x18\x03 \x01(\x11\"\x8e\x01\n\x1b\x43onfigureArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fsequence_handle\x18\x03 \x01(\x11\x12\x0c\n\x04gain\x18\x04 \x01(\x01\x12\x0e\n\x06offset\x18\x05 \x01(\x01\".\n\x1c\x43onfigureArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x17\x43learArbSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x36\n\x0fsequence_handle\x18\x02 \x01(\x0e\x32\x1b.nifgen_grpc.SequenceHandleH\x00\x12\x1d\n\x13sequence_handle_raw\x18\x03 \x01(\x11H\x00\x42\x16\n\x14sequence_handle_enum\"*\n\x18\x43learArbSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\";\n\x15\x43learArbMemoryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"(\n\x16\x43learArbMemoryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"F\n QueryFreqListCapabilitiesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\xa2\x02\n!QueryFreqListCapabilitiesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12$\n\x1cmaximum_number_of_freq_lists\x18\x02 \x01(\x11\x12%\n\x1dminimum_frequency_list_length\x18\x03 \x01(\x11\x12%\n\x1dmaximum_frequency_list_length\x18\x04 \x01(\x11\x12\'\n\x1fminimum_frequency_list_duration\x18\x05 \x01(\x01\x12\'\n\x1fmaximum_frequency_list_duration\x18\x06 \x01(\x01\x12\'\n\x1f\x66requency_list_duration_quantum\x18\x07 \x01(\x01\"\xc0\x01\n\x15\x43reateFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12)\n\x08waveform\x18\x02 \x01(\x0e\x32\x15.nifgen_grpc.WaveformH\x00\x12\x16\n\x0cwaveform_raw\x18\x03 \x01(\x11H\x00\x12\x17\n\x0f\x66requency_array\x18\x04 \x03(\x01\x12\x16\n\x0e\x64uration_array\x18\x05 \x03(\x01\x42\x0f\n\rwaveform_enum\"G\n\x16\x43reateFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1d\n\x15\x66requency_list_handle\x18\x02 \x01(\x11\"\xae\x01\n\x18\x43onfigureFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1d\n\x15\x66requency_list_handle\x18\x03 \x01(\x11\x12\x11\n\tamplitude\x18\x04 \x01(\x01\x12\x11\n\tdc_offset\x18\x05 \x01(\x01\x12\x13\n\x0bstart_phase\x18\x06 \x01(\x01\"+\n\x19\x43onfigureFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x01\n\x14\x43learFreqListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x42\n\x15\x66requency_list_handle\x18\x02 \x01(\x0e\x32!.nifgen_grpc.FrequencyListOptionsH\x00\x12#\n\x19\x66requency_list_handle_raw\x18\x03 \x01(\x11H\x00\x42\x1c\n\x1a\x66requency_list_handle_enum\"\'\n\x15\x43learFreqListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"^\n\x12WriteScriptRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\t\"%\n\x13WriteScriptResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n\x13\x44\x65leteScriptRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x13\n\x0bscript_name\x18\x03 \x01(\t\"&\n\x14\x44\x65leteScriptResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb9\x01\n\x13\x45xportSignalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12%\n\x06signal\x18\x02 \x01(\x0e\x32\x13.nifgen_grpc.SignalH\x00\x12\x14\n\nsignal_raw\x18\x03 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x04 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x05 \x01(\tB\r\n\x0bsignal_enum\"&\n\x14\x45xportSignalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x02\n\x15RouteSignalOutRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x39\n\x11route_signal_from\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.RouteSignalFromH\x00\x12\x1f\n\x15route_signal_from_raw\x18\x04 \x01(\x11H\x00\x12\x35\n\x0froute_signal_to\x18\x05 \x01(\x0e\x32\x1a.nifgen_grpc.RouteSignalToH\x01\x12\x1d\n\x13route_signal_to_raw\x18\x06 \x01(\x11H\x01\x42\x18\n\x16route_signal_from_enumB\x16\n\x14route_signal_to_enum\"(\n\x16RouteSignalOutResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa8\x01\n\x1eSendSoftwareEdgeTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\'\n\x07trigger\x18\x02 \x01(\x0e\x32\x14.nifgen_grpc.TriggerH\x00\x12\x15\n\x0btrigger_raw\x18\x03 \x01(\x11H\x00\x12\x12\n\ntrigger_id\x18\x04 \x01(\tB\x0e\n\x0ctrigger_enum\"1\n\x1fSendSoftwareEdgeTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"k\n\'ConfigureDigitalEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04\x65\x64ge\x18\x03 \x01(\x11\":\n(ConfigureDigitalEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isableStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isableStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n/ConfigureP2PEndpointFullnessStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12#\n\x1bp2p_endpoint_fullness_level\x18\x02 \x01(\x11\"B\n0ConfigureP2PEndpointFullnessStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x80\x01\n(ConfigureDigitalEdgeScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x0c\n\x04\x65\x64ge\x18\x04 \x01(\x11\";\n)ConfigureDigitalEdgeScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd6\x01\n)ConfigureDigitalLevelScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x30\n\x0ctrigger_when\x18\x04 \x01(\x0e\x32\x18.nifgen_grpc.TriggerWhenH\x00\x12\x1a\n\x10trigger_when_raw\x18\x05 \x01(\x11H\x00\x42\x13\n\x11trigger_when_enum\"<\n*ConfigureDigitalLevelScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n)ConfigureSoftwareEdgeScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\"<\n*ConfigureSoftwareEdgeScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x1b\x44isableScriptTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\ntrigger_id\x18\x02 \x01(\t\".\n\x1c\x44isableScriptTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9a\x01\n\x19\x43onfigureClockModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12,\n\nclock_mode\x18\x02 \x01(\x0e\x32\x16.nifgen_grpc.ClockModeH\x00\x12\x18\n\x0e\x63lock_mode_raw\x18\x03 \x01(\x11H\x00\x42\x11\n\x0f\x63lock_mode_enum\",\n\x1a\x43onfigureClockModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n%AdjustSampleClockRelativeDelayRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x61\x64justment_time\x18\x02 \x01(\x01\"8\n&AdjustSampleClockRelativeDelayResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x17\x41llocateWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rwaveform_size\x18\x03 \x01(\x11\"C\n\x18\x41llocateWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11\"\xe7\x01\n#SetWaveformNextWritePositionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12.\n\x0brelative_to\x18\x04 \x01(\x0e\x32\x17.nifgen_grpc.RelativeToH\x00\x12\x19\n\x0frelative_to_raw\x18\x05 \x01(\x11H\x00\x12\x0e\n\x06offset\x18\x06 \x01(\x11\x42\x12\n\x10relative_to_enum\"6\n$SetWaveformNextWritePositionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"w\n\x14WriteWaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x01\"\'\n\x15WriteWaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x7f\n\x1cWriteBinary16WaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\x11\"/\n\x1dWriteBinary16WaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa1\x01\n\x1eWriteWaveformComplexF64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12,\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x17\n\x0fwaveform_handle\x18\x04 \x01(\x11\"1\n\x1fWriteWaveformComplexF64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa3\x01\n#WriteComplexBinary16WaveformRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x17\n\x0fwaveform_handle\x18\x03 \x01(\x11\x12)\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x1b.nidevice_grpc.NIComplexI16\"6\n$WriteComplexBinary16WaveformResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0eSelfCalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0fSelfCalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1aGetSelfCalSupportedRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"I\n\x1bGetSelfCalSupportedResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12self_cal_supported\x18\x02 \x01(\x08\"F\n GetSelfCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"{\n!GetSelfCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"E\n\x1fGetExtCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"z\n GetExtCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"?\n\x19GetSelfCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"A\n\x1aGetSelfCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\">\n\x18GetExtCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"@\n\x19GetExtCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"I\n#GetExtCalRecommendedIntervalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"F\n$GetExtCalRecommendedIntervalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x11\"C\n\x1dReadCurrentTemperatureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x1eReadCurrentTemperatureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"\x83\x01\n+ConfigureCustomFIRFilterCoefficientsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12\x63oefficients_array\x18\x03 \x03(\x01\">\n,ConfigureCustomFIRFilterCoefficientsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x1fGetFIRFilterCoefficientsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"s\n GetFIRFilterCoefficientsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1a\n\x12\x63oefficients_array\x18\x02 \x03(\x01\x12#\n\x1bnumber_of_coefficients_read\x18\x03 \x01(\x11\"]\n\x1eGetStreamEndpointHandleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0fstream_endpoint\x18\x02 \x01(\t\"H\n\x1fGetStreamEndpointHandleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rreader_handle\x18\x02 \x01(\r\"n\n\x1aWriteP2PEndpointI16Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rendpoint_name\x18\x02 \x01(\t\x12\x15\n\rendpoint_data\x18\x03 \x03(\x11\"-\n\x1bWriteP2PEndpointI16Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"{\n\x1f\x43onfigureSynchronizationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16synchronization_source\x18\x03 \x01(\x11\"2\n ConfigureSynchronizationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1e\x45nableDigitalPatterningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"1\n\x1f\x45nableDigitalPatterningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x1f\x44isableDigitalPatterningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"2\n DisableDigitalPatterningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"V\n\x1a\x45nableDigitalFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"-\n\x1b\x45nableDigitalFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"W\n\x1b\x44isableDigitalFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\".\n\x1c\x44isableDigitalFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n\x19\x45nableAnalogFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12#\n\x1b\x66ilter_correction_frequency\x18\x03 \x01(\x01\",\n\x1a\x45nableAnalogFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"V\n\x1a\x44isableAnalogFilterRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"-\n\x1b\x44isableAnalogFilterResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"d\n!ConfigureSampleClockSourceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1b\n\x13sample_clock_source\x18\x02 \x01(\t\"4\n\"ConfigureSampleClockSourceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n\x1b\x43onfigureTriggerModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x30\n\x0ctrigger_mode\x18\x03 \x01(\x0e\x32\x18.nifgen_grpc.TriggerModeH\x00\x12\x1a\n\x10trigger_mode_raw\x18\x04 \x01(\x11H\x00\x42\x13\n\x11trigger_mode_enum\".\n\x1c\x43onfigureTriggerModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ImportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ImportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ExportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ExportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"f\n)ImportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"<\n*ImportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n)ExportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"S\n*ExportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"\xa7\x01\n\x1aSetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"-\n\x1bSetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa9\x01\n\x1c\x43heckAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"/\n\x1d\x43heckAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8a\x01\n\x1aGetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"F\n\x1bGetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x03\"\x85\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x42\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32\'.nifgen_grpc.NiFgenInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x02\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x43\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32(.nifgen_grpc.NiFgenReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x94\x02\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\tH\x00\x12P\n\x16\x61ttribute_value_mapped\x18\x05 \x01(\x0e\x32..nifgen_grpc.NiFgenStringAttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa5\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x87\x02\n\x1c\x43heckAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x42\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32\'.nifgen_grpc.NiFgenInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"/\n\x1d\x43heckAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x89\x02\n\x1d\x43heckAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x43\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32(.nifgen_grpc.NiFgenReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\"0\n\x1e\x43heckAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x96\x02\n\x1d\x43heckAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\tH\x00\x12P\n\x16\x61ttribute_value_mapped\x18\x05 \x01(\x0e\x32..nifgen_grpc.NiFgenStringAttributeValuesMappedH\x00\x42\x16\n\x14\x61ttribute_value_enum\"0\n\x1e\x43heckAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa7\x01\n\x1e\x43heckAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"1\n\x1f\x43heckAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbf\x01\n\x1e\x43heckAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1f\x43heckAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8a\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x8b\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x8b\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\"\x8c\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"\x8c\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x85\x01\n\x15ResetAttributeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\x1c.nifgen_grpc.NiFgenAttribute\"(\n\x16ResetAttributeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Y\n\x1cManualEnableP2PStreamRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rendpoint_name\x18\x02 \x01(\t\"/\n\x1dManualEnableP2PStreamResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xba\x01\n CreateWaveformFromFileHWSRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x1e\n\x16use_rate_from_waveform\x18\x04 \x01(\x08\x12)\n!use_gain_and_offset_from_waveform\x18\x05 \x01(\x08\"L\n!CreateWaveformFromFileHWSResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0fwaveform_handle\x18\x02 \x01(\x11*\xa9S\n\x0fNiFgenAttribute\x12 \n\x1cNIFGEN_ATTRIBUTE_UNSPECIFIED\x10\x00\x12\"\n\x1cNIFGEN_ATTRIBUTE_OUTPUT_MODE\x10\xd1\xa5L\x12%\n\x1fNIFGEN_ATTRIBUTE_OUTPUT_ENABLED\x10\xd3\xa5L\x12#\n\x1dNIFGEN_ATTRIBUTE_DIGITAL_GAIN\x10\xae\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_ANALOG_PATH\x10\x8e\x9a\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_LOAD_IMPEDANCE\x10\x8c\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_OUTPUT_IMPEDANCE\x10\xd4\xa5L\x12-\n\'NIFGEN_ATTRIBUTE_TERMINAL_CONFIGURATION\x10\x9d\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_COMMON_MODE_OFFSET\x10\x9e\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_CHANNEL_DELAY\x10\xa1\x9b\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_ABSOLUTE_DELAY\x10\xcd\x9b\x46\x12,\n&NIFGEN_ATTRIBUTE_ANALOG_FILTER_ENABLED\x10\x97\x99\x46\x12-\n\'NIFGEN_ATTRIBUTE_DIGITAL_FILTER_ENABLED\x10\x96\x99\x46\x12:\n4NIFGEN_ATTRIBUTE_DIGITAL_FILTER_INTERPOLATION_FACTOR\x10\x8a\x9a\x46\x12\x32\n,NIFGEN_ATTRIBUTE_FLATNESS_CORRECTION_ENABLED\x10\xf3\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_ANALOG_DATA_MASK\x10\x9a\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_ANALOG_STATIC_VALUE\x10\x9b\x9a\x46\x12(\n\"NIFGEN_ATTRIBUTE_DIGITAL_DATA_MASK\x10\x9c\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_DIGITAL_STATIC_VALUE\x10\x9d\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_DIGITAL_PATTERN_ENABLED\x10\x95\x99\x46\x12(\n\"NIFGEN_ATTRIBUTE_AUX_POWER_ENABLED\x10\xcb\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_IDLE_BEHAVIOR\x10\xa9\x9b\x46\x12!\n\x1bNIFGEN_ATTRIBUTE_IDLE_VALUE\x10\xaa\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_WAIT_BEHAVIOR\x10\xab\x9b\x46\x12!\n\x1bNIFGEN_ATTRIBUTE_WAIT_VALUE\x10\xac\x9b\x46\x12\x1f\n\x19NIFGEN_ATTRIBUTE_ARB_GAIN\x10\x9a\xa7L\x12!\n\x1bNIFGEN_ATTRIBUTE_ARB_OFFSET\x10\x9b\xa7L\x12\'\n!NIFGEN_ATTRIBUTE_WAVEFORM_QUANTUM\x10\x9e\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_NUM_WAVEFORMS\x10\x9d\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MIN_WAVEFORM_SIZE\x10\x9f\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_WAVEFORM_SIZE\x10\xa0\xa7L\x12*\n$NIFGEN_ATTRIBUTE_ARB_WAVEFORM_HANDLE\x10\x99\xa7L\x12*\n$NIFGEN_ATTRIBUTE_ARB_MARKER_POSITION\x10\xf7\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_ARB_REPEAT_COUNT\x10\xf8\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_ARB_SEQUENCE_HANDLE\x10\xa3\xa7L\x12(\n\"NIFGEN_ATTRIBUTE_MAX_NUM_SEQUENCES\x10\xa4\xa7L\x12*\n$NIFGEN_ATTRIBUTE_MIN_SEQUENCE_LENGTH\x10\xa5\xa7L\x12*\n$NIFGEN_ATTRIBUTE_MAX_SEQUENCE_LENGTH\x10\xa6\xa7L\x12%\n\x1fNIFGEN_ATTRIBUTE_MAX_LOOP_COUNT\x10\xa7\xa7L\x12)\n#NIFGEN_ATTRIBUTE_SCRIPT_TO_GENERATE\x10\xbe\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_FILE_TRANSFER_BLOCK_SIZE\x10\xa0\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_DATA_TRANSFER_BLOCK_SIZE\x10\xa1\x9a\x46\x12\x36\n0NIFGEN_ATTRIBUTE_DATA_TRANSFER_MAXIMUM_BANDWIDTH\x10\xa5\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_DIRECT_DMA_ENABLED\x10\xa4\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_DIRECT_DMA_WINDOW_SIZE\x10\xa5\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DIRECT_DMA_WINDOW_ADDRESS\x10\xc2\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_STREAMING_WAVEFORM_NAME\x10\xf6\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STREAMING_WAVEFORM_HANDLE\x10\xf4\x9a\x46\x12<\n6NIFGEN_ATTRIBUTE_STREAMING_SPACE_AVAILABLE_IN_WAVEFORM\x10\xf5\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_STREAMING_WRITE_TIMEOUT\x10\xc9\x9b\x46\x12:\n4NIFGEN_ATTRIBUTE_DATA_TRANSFER_PREFERRED_PACKET_SIZE\x10\xa6\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_DATA_TRANSFER_MAXIMUM_IN_FLIGHT_READS\x10\xa7\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_PCI_DMA_OPTIMIZATIONS_ENABLED\x10\x9a\x9b\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_OSP_ENABLED\x10\xa6\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_OSP_IQ_RATE\x10\xa8\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_OSP_DATA_PROCESSING_MODE\x10\xa7\x9a\x46\x12\x1f\n\x19NIFGEN_ATTRIBUTE_OSP_MODE\x10\xa2\x9b\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_FREQUENCY_SHIFT\x10\xa3\x9b\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_ENABLED\x10\xa9\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_CARRIER_FREQUENCY\x10\xaa\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_PHASE_I\x10\xab\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CARRIER_PHASE_Q\x10\xac\x9a\x46\x12<\n6NIFGEN_ATTRIBUTE_OSP_COMPENSATE_FOR_FILTER_GROUP_DELAY\x10\xb5\x9b\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_TYPE\x10\xad\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_ENABLED\x10\xaf\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_INTERPOLATION\x10\xb0\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_ENABLED\x10\xb1\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_INTERPOLATION\x10\xb2\x9a\x46\x12>\n8NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_ROOT_RAISED_COSINE_ALPHA\x10\xb3\x9a\x46\x12\x39\n3NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_RAISED_COSINE_ALPHA\x10\xb4\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_FLAT_PASSBAND\x10\xb5\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_OSP_FIR_FILTER_GAUSSIAN_BT\x10\xb6\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_CIC_FILTER_GAIN\x10\xb7\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_GAIN_I\x10\xb8\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_GAIN_Q\x10\xb9\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_OFFSET_I\x10\xba\x9a\x46\x12.\n(NIFGEN_ATTRIBUTE_OSP_PRE_FILTER_OFFSET_Q\x10\xbb\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_OSP_OVERFLOW_ERROR_REPORTING\x10\xbc\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_OSP_OVERFLOW_STATUS\x10\xbd\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_P2P_ENABLED\x10\xb7\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_P2P_DESTINATION_CHANNELS\x10\xb8\x9b\x46\x12(\n\"NIFGEN_ATTRIBUTE_P2P_ENDPOINT_SIZE\x10\xb9\x9b\x46\x12\x36\n0NIFGEN_ATTRIBUTE_P2P_SPACE_AVAILABLE_IN_ENDPOINT\x10\xba\x9b\x46\x12;\n5NIFGEN_ATTRIBUTE_P2P_MOST_SPACE_AVAILABLE_IN_ENDPOINT\x10\xbb\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_P2P_ENDPOINT_COUNT\x10\xbc\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_INTERVAL\x10\xc0\x9b\x46\x12\x43\n=NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_INITIAL_CREDITS\x10\xc8\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_P2P_MANUAL_CONFIGURATION_ENABLED\x10\xbd\x9b\x46\x12;\n5NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_ADDRESS\x10\xbe\x9b\x46\x12@\n:NIFGEN_ATTRIBUTE_P2P_DATA_TRANSFER_PERMISSION_ADDRESS_TYPE\x10\xbf\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_ADDRESS\x10\xc1\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_ADDRESS_TYPE\x10\xc2\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_P2P_ENDPOINT_WINDOW_SIZE\x10\xc3\x9b\x46\x12@\n:NIFGEN_ATTRIBUTE_P2P_ENDPOINT_FULLNESS_START_TRIGGER_LEVEL\x10\xca\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_ADDRESS\x10\xc5\x9b\x46\x12\x39\n3NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_ADDRESS_TYPE\x10\xc6\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_P2P_DONE_NOTIFICATION_VALUE\x10\xc7\x9b\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_FUNC_WAVEFORM\x10\xb5\xa6L\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_AMPLITUDE\x10\xb6\xa6L\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_DC_OFFSET\x10\xb7\xa6L\x12\'\n!NIFGEN_ATTRIBUTE_FUNC_START_PHASE\x10\xb9\xa6L\x12+\n%NIFGEN_ATTRIBUTE_FUNC_DUTY_CYCLE_HIGH\x10\xba\xa6L\x12+\n%NIFGEN_ATTRIBUTE_SYNC_DUTY_CYCLE_HIGH\x10\x99\x99\x46\x12/\n)NIFGEN_ATTRIBUTE_SYNC_OUT_OUTPUT_TERMINAL\x10\xfa\x9a\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_FUNC_FREQUENCY\x10\xb8\xa6L\x12\'\n!NIFGEN_ATTRIBUTE_FUNC_BUFFER_SIZE\x10\x9e\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_FUNC_MAX_BUFFER_SIZE\x10\x9f\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_FREQ_LIST_HANDLE\x10\x80\x9a\x46\x12)\n#NIFGEN_ATTRIBUTE_MAX_NUM_FREQ_LISTS\x10\x81\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_MIN_FREQ_LIST_LENGTH\x10\x82\x9a\x46\x12+\n%NIFGEN_ATTRIBUTE_MAX_FREQ_LIST_LENGTH\x10\x83\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_MIN_FREQ_LIST_DURATION\x10\x84\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_MAX_FREQ_LIST_DURATION\x10\x85\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_FREQ_LIST_DURATION_QUANTUM\x10\x86\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_REFERENCE_CLOCK_SOURCE\x10\xa1\x99\x46\x12*\n$NIFGEN_ATTRIBUTE_REF_CLOCK_FREQUENCY\x10\x9b\x99\x46\x12?\n9NIFGEN_ATTRIBUTE_EXPORTED_REFERENCE_CLOCK_OUTPUT_TERMINAL\x10\xf1\x9a\x46\x12G\nANIFGEN_ATTRIBUTE_EXPORTED_ONBOARD_REFERENCE_CLOCK_OUTPUT_TERMINAL\x10\xf2\x9a\x46\x12&\n NIFGEN_ATTRIBUTE_ARB_SAMPLE_RATE\x10\x9c\xa7L\x12!\n\x1bNIFGEN_ATTRIBUTE_CLOCK_MODE\x10\x9e\x99\x46\x12*\n$NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_SOURCE\x10\xa0\x99\x46\x12<\n6NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_OUTPUT_TERMINAL\x10\xf0\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_DIVISOR\x10\x8b\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_TIMEBASE_SOURCE\x10\x9f\x9b\x46\x12\x31\n+NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_TIMEBASE_RATE\x10\xa0\x9b\x46\x12\x45\n?NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_TIMEBASE_OUTPUT_TERMINAL\x10\xf9\x9a\x46\x12=\n7NIFGEN_ATTRIBUTE_EXPORTED_SAMPLE_CLOCK_TIMEBASE_DIVISOR\x10\x96\x9a\x46\x12\x37\n1NIFGEN_ATTRIBUTE_EXTERNAL_SAMPLE_CLOCK_MULTIPLIER\x10\xa8\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_SAMPLE_CLOCK_ABSOLUTE_DELAY\x10\x97\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_OSCILLATOR_PHASE_DAC_VALUE\x10\x98\x9a\x46\x12\x38\n2NIFGEN_ATTRIBUTE_EXTERNAL_CLOCK_DELAY_BINARY_VALUE\x10\x99\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_MARKER_EVENT_OUTPUT_TERMINAL\x10\xe8\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_MARKER_EVENT_OUTPUT_BEHAVIOR\x10\x86\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_POLARITY\x10\xe9\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_WIDTH\x10\x84\x9b\x46\x12\x35\n/NIFGEN_ATTRIBUTE_MARKER_EVENT_PULSE_WIDTH_UNITS\x10\x85\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_MARKER_EVENT_TOGGLE_INITIAL_STATE\x10\x87\x9b\x46\x12)\n#NIFGEN_ATTRIBUTE_MARKER_EVENT_DELAY\x10\x92\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_DELAY_UNITS\x10\x93\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_ALL_MARKER_EVENTS_LIVE_STATUS\x10\x88\x9b\x46\x12/\n)NIFGEN_ATTRIBUTE_MARKER_EVENT_LIVE_STATUS\x10\x89\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_ALL_MARKER_EVENTS_LATCHED_STATUS\x10\x8d\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_MARKER_EVENT_LATCHED_STATUS\x10\x8e\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_DATA_BIT_NUMBER\x10\x81\x9b\x46\x12\x37\n1NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_LEVEL_POLARITY\x10\x82\x9b\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DATA_MARKER_EVENT_OUTPUT_TERMINAL\x10\x83\x9b\x46\x12<\n6NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_OUTPUT_TERMINAL\x10\xe6\x9a\x46\x12?\n9NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_LEVEL_ACTIVE_LEVEL\x10\xe7\x9a\x46\x12\x38\n2NIFGEN_ATTRIBUTE_READY_FOR_START_EVENT_LIVE_STATUS\x10\x8c\x9b\x46\x12\x34\n.NIFGEN_ATTRIBUTE_STARTED_EVENT_OUTPUT_TERMINAL\x10\xea\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_STARTED_EVENT_OUTPUT_BEHAVIOR\x10\xfb\x9a\x46\x12\x37\n1NIFGEN_ATTRIBUTE_STARTED_EVENT_LEVEL_ACTIVE_LEVEL\x10\xec\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_POLARITY\x10\xee\x9a\x46\x12\x36\n0NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_WIDTH_UNITS\x10\xfd\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STARTED_EVENT_PULSE_WIDTH\x10\xff\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_STARTED_EVENT_DELAY\x10\x94\x9b\x46\x12\x30\n*NIFGEN_ATTRIBUTE_STARTED_EVENT_DELAY_UNITS\x10\x95\x9b\x46\x12\x33\n-NIFGEN_ATTRIBUTE_STARTED_EVENT_LATCHED_STATUS\x10\x90\x9b\x46\x12\x31\n+NIFGEN_ATTRIBUTE_DONE_EVENT_OUTPUT_TERMINAL\x10\xeb\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_DONE_EVENT_OUTPUT_BEHAVIOR\x10\xfc\x9a\x46\x12\x34\n.NIFGEN_ATTRIBUTE_DONE_EVENT_LEVEL_ACTIVE_LEVEL\x10\xed\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_POLARITY\x10\xef\x9a\x46\x12\x33\n-NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_WIDTH_UNITS\x10\xfe\x9a\x46\x12-\n\'NIFGEN_ATTRIBUTE_DONE_EVENT_PULSE_WIDTH\x10\x80\x9b\x46\x12\'\n!NIFGEN_ATTRIBUTE_DONE_EVENT_DELAY\x10\x96\x9b\x46\x12-\n\'NIFGEN_ATTRIBUTE_DONE_EVENT_DELAY_UNITS\x10\x97\x9b\x46\x12\x30\n*NIFGEN_ATTRIBUTE_DONE_EVENT_LATCHED_STATUS\x10\x8f\x9b\x46\x12#\n\x1dNIFGEN_ATTRIBUTE_TRIGGER_MODE\x10\x9c\x99\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_BURST_COUNT\x10\xae\xa8L\x12)\n#NIFGEN_ATTRIBUTE_START_TRIGGER_TYPE\x10\xc8\x9a\x46\x12\x38\n2NIFGEN_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_SOURCE\x10\xc9\x9a\x46\x12\x36\n0NIFGEN_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_EDGE\x10\xca\x9a\x46\x12=\n7NIFGEN_ATTRIBUTE_EXPORTED_START_TRIGGER_OUTPUT_TERMINAL\x10\xcb\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_SCRIPT_TRIGGER_TYPE\x10\xd2\x9a\x46\x12\x39\n3NIFGEN_ATTRIBUTE_DIGITAL_EDGE_SCRIPT_TRIGGER_SOURCE\x10\xd3\x9a\x46\x12\x37\n1NIFGEN_ATTRIBUTE_DIGITAL_EDGE_SCRIPT_TRIGGER_EDGE\x10\xd4\x9a\x46\x12:\n4NIFGEN_ATTRIBUTE_DIGITAL_LEVEL_SCRIPT_TRIGGER_SOURCE\x10\xd5\x9a\x46\x12@\n:NIFGEN_ATTRIBUTE_DIGITAL_LEVEL_SCRIPT_TRIGGER_ACTIVE_LEVEL\x10\xd6\x9a\x46\x12>\n8NIFGEN_ATTRIBUTE_EXPORTED_SCRIPT_TRIGGER_OUTPUT_TERMINAL\x10\xd7\x9a\x46\x12\x1f\n\x19NIFGEN_ATTRIBUTE_BUS_TYPE\x10\x87\x9a\x46\x12\"\n\x1cNIFGEN_ATTRIBUTE_MEMORY_SIZE\x10\xa2\x9a\x46\x12$\n\x1eNIFGEN_ATTRIBUTE_SERIAL_NUMBER\x10\xa3\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_MARKER_EVENTS_COUNT\x10\xbf\x9a\x46\x12/\n)NIFGEN_ATTRIBUTE_DATA_MARKER_EVENTS_COUNT\x10\xc1\x9a\x46\x12,\n&NIFGEN_ATTRIBUTE_SCRIPT_TRIGGERS_COUNT\x10\xc0\x9a\x46\x12*\n$NIFGEN_ATTRIBUTE_VIDEO_WAVEFORM_TYPE\x10\x88\x9a\x46\x12(\n\"NIFGEN_ATTRIBUTE_FPGA_BITFILE_PATH\x10\xcc\x9b\x46\x12\x32\n,NIFGEN_ATTRIBUTE_FILTER_CORRECTION_FREQUENCY\x10\x98\x99\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_TRIGGER_SOURCE\x10\xfe\xa7L\x12&\n NIFGEN_ATTRIBUTE_SYNCHRONIZATION\x10\x9f\x99\x46\x12(\n\"NIFGEN_ATTRIBUTE_ID_QUERY_RESPONSE\x10\xb1\x98\x46\x12%\n\x1fNIFGEN_ATTRIBUTE_GAIN_DAC_VALUE\x10\x8f\x9a\x46\x12\'\n!NIFGEN_ATTRIBUTE_OFFSET_DAC_VALUE\x10\x90\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_OSCILLATOR_FREQ_DAC_VALUE\x10\x91\x9a\x46\x12\x30\n*NIFGEN_ATTRIBUTE_PRE_AMPLIFIER_ATTENUATION\x10\x94\x9a\x46\x12\x31\n+NIFGEN_ATTRIBUTE_POST_AMPLIFIER_ATTENUATION\x10\x95\x9a\x46\x12\x1c\n\x16NIFGEN_ATTRIBUTE_CACHE\x10\x94\x8b@\x12\"\n\x1cNIFGEN_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12.\n(NIFGEN_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\'\n!NIFGEN_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12\x1f\n\x19NIFGEN_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12(\n\"NIFGEN_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12\x32\n,NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12-\n\'NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12-\n\'NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12/\n)NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12?\n9NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12?\n9NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12\x32\n,NIFGEN_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12)\n#NIFGEN_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12$\n\x1eNIFGEN_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12.\n(NIFGEN_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12\'\n!NIFGEN_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12\x33\n-NIFGEN_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12&\n NIFGEN_ATTRIBUTE_MODULE_REVISION\x10\xb6\x9b\x46\x12-\n\'NIFGEN_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12#\n\x1dNIFGEN_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12#\n\x1dNIFGEN_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12\x34\n.NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_MAJOR_VERSION\x10\x87\x8f@\x12\x34\n.NIFGEN_ATTRIBUTE_SPECIFIC_DRIVER_MINOR_VERSION\x10\x88\x8f@\x12*\n$NIFGEN_ATTRIBUTE_UPDATE_CLOCK_SOURCE\x10\x9a\x99\x46*\xd9\x01\n\nOutputMode\x12&\n\"OUTPUT_MODE_NIFGEN_VAL_OUTPUT_FUNC\x10\x00\x12%\n!OUTPUT_MODE_NIFGEN_VAL_OUTPUT_ARB\x10\x01\x12%\n!OUTPUT_MODE_NIFGEN_VAL_OUTPUT_SEQ\x10\x02\x12+\n\'OUTPUT_MODE_NIFGEN_VAL_OUTPUT_FREQ_LIST\x10\x65\x12(\n$OUTPUT_MODE_NIFGEN_VAL_OUTPUT_SCRIPT\x10\x66*\xc1\x02\n\x08Waveform\x12\x18\n\x14WAVEFORM_UNSPECIFIED\x10\x00\x12 \n\x1cWAVEFORM_NIFGEN_VAL_WFM_SINE\x10\x01\x12\"\n\x1eWAVEFORM_NIFGEN_VAL_WFM_SQUARE\x10\x02\x12$\n WAVEFORM_NIFGEN_VAL_WFM_TRIANGLE\x10\x03\x12#\n\x1fWAVEFORM_NIFGEN_VAL_WFM_RAMP_UP\x10\x04\x12%\n!WAVEFORM_NIFGEN_VAL_WFM_RAMP_DOWN\x10\x05\x12\x1e\n\x1aWAVEFORM_NIFGEN_VAL_WFM_DC\x10\x06\x12!\n\x1dWAVEFORM_NIFGEN_VAL_WFM_NOISE\x10\x65\x12 \n\x1cWAVEFORM_NIFGEN_VAL_WFM_USER\x10\x66*\xa0\x04\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12.\n)SIGNAL_NIFGEN_VAL_ONBOARD_REFERENCE_CLOCK\x10\xfb\x07\x12\x1f\n\x1aSIGNAL_NIFGEN_VAL_SYNC_OUT\x10\xea\x07\x12$\n\x1fSIGNAL_NIFGEN_VAL_START_TRIGGER\x10\xec\x07\x12#\n\x1eSIGNAL_NIFGEN_VAL_MARKER_EVENT\x10\xe9\x07\x12,\n\'SIGNAL_NIFGEN_VAL_SAMPLE_CLOCK_TIMEBASE\x10\xee\x07\x12&\n!SIGNAL_NIFGEN_VAL_SYNCHRONIZATION\x10\xef\x07\x12\"\n\x1eSIGNAL_NIFGEN_VAL_SAMPLE_CLOCK\x10\x65\x12%\n!SIGNAL_NIFGEN_VAL_REFERENCE_CLOCK\x10\x66\x12$\n SIGNAL_NIFGEN_VAL_SCRIPT_TRIGGER\x10g\x12+\n\'SIGNAL_NIFGEN_VAL_READY_FOR_START_EVENT\x10i\x12#\n\x1fSIGNAL_NIFGEN_VAL_STARTED_EVENT\x10j\x12 \n\x1cSIGNAL_NIFGEN_VAL_DONE_EVENT\x10k\x12\'\n#SIGNAL_NIFGEN_VAL_DATA_MARKER_EVENT\x10l*\xbf\x01\n\x0bTriggerMode\x12\x1c\n\x18TRIGGER_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1eTRIGGER_MODE_NIFGEN_VAL_SINGLE\x10\x01\x12&\n\"TRIGGER_MODE_NIFGEN_VAL_CONTINUOUS\x10\x02\x12#\n\x1fTRIGGER_MODE_NIFGEN_VAL_STEPPED\x10\x03\x12!\n\x1dTRIGGER_MODE_NIFGEN_VAL_BURST\x10\x04*\x82\x01\n\tClockMode\x12)\n%CLOCK_MODE_NIFGEN_VAL_HIGH_RESOLUTION\x10\x00\x12%\n!CLOCK_MODE_NIFGEN_VAL_DIVIDE_DOWN\x10\x01\x12#\n\x1f\x43LOCK_MODE_NIFGEN_VAL_AUTOMATIC\x10\x02*v\n\nRelativeTo\x12\x32\n.RELATIVE_TO_NIFGEN_VAL_WAVEFORM_POSITION_START\x10\x00\x12\x34\n0RELATIVE_TO_NIFGEN_VAL_WAVEFORM_POSITION_CURRENT\x10\x01*\xe8\x01\n\rHardwareState\x12\"\n\x1eHARDWARE_STATE_NIFGEN_VAL_IDLE\x10\x00\x12\x37\n3HARDWARE_STATE_NIFGEN_VAL_WAITING_FOR_START_TRIGGER\x10\x64\x12&\n!HARDWARE_STATE_NIFGEN_VAL_RUNNING\x10\xc8\x01\x12#\n\x1eHARDWARE_STATE_NIFGEN_VAL_DONE\x10\xd8\x04\x12-\n(HARDWARE_STATE_NIFGEN_VAL_HARDWARE_ERROR\x10\xe8\x07*Z\n\tByteOrder\x12\'\n#BYTE_ORDER_NIFGEN_VAL_LITTLE_ENDIAN\x10\x00\x12$\n BYTE_ORDER_NIFGEN_VAL_BIG_ENDIAN\x10\x01*|\n\x0bTriggerWhen\x12\x1c\n\x18TRIGGER_WHEN_UNSPECIFIED\x10\x00\x12\'\n#TRIGGER_WHEN_NIFGEN_VAL_ACTIVE_HIGH\x10\x65\x12&\n\"TRIGGER_WHEN_NIFGEN_VAL_ACTIVE_LOW\x10\x66*p\n\x07Trigger\x12\x17\n\x13TRIGGER_UNSPECIFIED\x10\x00\x12%\n TRIGGER_NIFGEN_VAL_START_TRIGGER\x10\xec\x07\x12%\n!TRIGGER_NIFGEN_VAL_SCRIPT_TRIGGER\x10g*y\n\x14\x46requencyListOptions\x12&\n\"FREQUENCY_LIST_OPTIONS_UNSPECIFIED\x10\x00\x12\x39\n,FREQUENCY_LIST_OPTIONS_NIFGEN_VAL_ALL_FLISTS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*\x89\x07\n\x0fRouteSignalFrom\x12!\n\x1dROUTE_SIGNAL_FROM_UNSPECIFIED\x10\x00\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_MARKER\x10\xe9\x07\x12*\n%ROUTE_SIGNAL_FROM_NIFGEN_VAL_SYNC_OUT\x10\xea\x07\x12\x33\n.ROUTE_SIGNAL_FROM_NIFGEN_VAL_OUT_START_TRIGGER\x10\xec\x07\x12-\n(ROUTE_SIGNAL_FROM_NIFGEN_VAL_BOARD_CLOCK\x10\xee\x07\x12\x31\n,ROUTE_SIGNAL_FROM_NIFGEN_VAL_SYNCHRONIZATION\x10\xef\x07\x12.\n*ROUTE_SIGNAL_FROM_NIFGEN_VAL_SOFTWARE_TRIG\x10\x02\x12)\n$ROUTE_SIGNAL_FROM_NIFGEN_VAL_REF_OUT\x10\xf0\x07\x12+\n&ROUTE_SIGNAL_FROM_NIFGEN_VAL_CLOCK_OUT\x10\xf1\x07\x12*\n%ROUTE_SIGNAL_FROM_NIFGEN_VAL_PXI_STAR\x10\x83\x01\x12\'\n\"ROUTE_SIGNAL_FROM_NIFGEN_VAL_PFI_0\x10\xf3\x07\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_0\x10\x8d\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_1\x10\x8e\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_2\x10\x8f\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_3\x10\x90\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_4\x10\x91\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_5\x10\x92\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_6\x10\x93\x01\x12(\n#ROUTE_SIGNAL_FROM_NIFGEN_VAL_RTSI_7\x10\xf2\x07\x12\x39\n4ROUTE_SIGNAL_FROM_NIFGEN_VAL_ONBOARD_REFERENCE_CLOCK\x10\xfb\x07*\x91\x04\n\rRouteSignalTo\x12\x1f\n\x1bROUTE_SIGNAL_TO_UNSPECIFIED\x10\x00\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_0\x10\x8d\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_1\x10\x8e\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_2\x10\x8f\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_3\x10\x90\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_4\x10\x91\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_5\x10\x92\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_6\x10\x93\x01\x12&\n!ROUTE_SIGNAL_TO_NIFGEN_VAL_RTSI_7\x10\xf2\x07\x12\'\n\"ROUTE_SIGNAL_TO_NIFGEN_VAL_REF_OUT\x10\xf0\x07\x12%\n ROUTE_SIGNAL_TO_NIFGEN_VAL_PFI_0\x10\xf3\x07\x12%\n ROUTE_SIGNAL_TO_NIFGEN_VAL_PFI_1\x10\xf4\x07\x12(\n#ROUTE_SIGNAL_TO_NIFGEN_VAL_PXI_STAR\x10\x83\x01*h\n\x0eSequenceHandle\x12\x1f\n\x1bSEQUENCE_HANDLE_UNSPECIFIED\x10\x00\x12\x35\n(SEQUENCE_HANDLE_NIFGEN_VAL_ALL_SEQUENCES\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*h\n\x0eWaveformHandle\x12\x1f\n\x1bWAVEFORM_HANDLE_UNSPECIFIED\x10\x00\x12\x35\n(WAVEFORM_HANDLE_NIFGEN_VAL_ALL_WAVEFORMS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xc1Q\n\x1aNiFgenInt32AttributeValues\x12\x1c\n\x18NIFGEN_INT32_UNSPECIFIED\x10\x00\x12/\n+NIFGEN_INT32_ADDRESS_TYPE_VAL_ADDR_PHYSICAL\x10\x00\x12.\n*NIFGEN_INT32_ADDRESS_TYPE_VAL_ADDR_VIRTUAL\x10\x01\x12\x31\n-NIFGEN_INT32_ANALOG_PATH_VAL_MAIN_ANALOG_PATH\x10\x00\x12\x33\n/NIFGEN_INT32_ANALOG_PATH_VAL_DIRECT_ANALOG_PATH\x10\x01\x12;\n7NIFGEN_INT32_ANALOG_PATH_VAL_FIXED_LOW_GAIN_ANALOG_PATH\x10\x02\x12<\n8NIFGEN_INT32_ANALOG_PATH_VAL_FIXED_HIGH_GAIN_ANALOG_PATH\x10\x03\x12\x46\n@NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_FIRST_SEQUENCE_HANDLE\x10\xa0\x8d\x06\x12\x45\n?NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_LAST_SEQUENCE_HANDLE\x10\xaf\xdb\x06\x12\x43\n6NIFGEN_INT32_ARBITRARY_SEQUENCE_HANDLE_VAL_NO_SEQUENCE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x45\n@NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_FIRST_WAVEFORM_HANDLE\x10\x90N\x12\x44\n?NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_LAST_WAVEFORM_HANDLE\x10\xf7U\x12\x43\n6NIFGEN_INT32_ARBITRARY_WAVEFORM_HANDLE_VAL_NO_WAVEFORM\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0NIFGEN_INT32_BURST_COUNT_VAL_GENERATE_CONTINUOUS\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n%NIFGEN_INT32_BUS_TYPE_VAL_BUS_INVALID\x10\x00\x12$\n NIFGEN_INT32_BUS_TYPE_VAL_BUS_AT\x10\x01\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_PCI\x10\x02\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_PXI\x10\x03\x12%\n!NIFGEN_INT32_BUS_TYPE_VAL_BUS_VXI\x10\x04\x12(\n$NIFGEN_INT32_BUS_TYPE_VAL_BUS_PCMCIA\x10\x05\x12&\n\"NIFGEN_INT32_BUS_TYPE_VAL_BUS_PXIE\x10\x06\x12/\n+NIFGEN_INT32_CLOCK_MODE_VAL_HIGH_RESOLUTION\x10\x00\x12+\n\'NIFGEN_INT32_CLOCK_MODE_VAL_DIVIDE_DOWN\x10\x01\x12)\n%NIFGEN_INT32_CLOCK_MODE_VAL_AUTOMATIC\x10\x02\x12\x41\n=NIFGEN_INT32_DATA_MARKER_EVENT_LEVEL_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12@\n<NIFGEN_INT32_DATA_MARKER_EVENT_LEVEL_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12\x32\n.NIFGEN_INT32_DATA_PROCESSING_MODE_VAL_OSP_REAL\x10\x00\x12\x35\n1NIFGEN_INT32_DATA_PROCESSING_MODE_VAL_OSP_COMPLEX\x10\x01\x12\x38\n4NIFGEN_INT32_DONE_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12\x37\n3NIFGEN_INT32_DONE_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12@\n<NIFGEN_INT32_DONE_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x33\n/NIFGEN_INT32_DONE_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x35\n1NIFGEN_INT32_DONE_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x35\n1NIFGEN_INT32_DONE_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12:\n6NIFGEN_INT32_DONE_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12\x39\n5NIFGEN_INT32_DONE_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12\x46\nBNIFGEN_INT32_DONE_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x39\n5NIFGEN_INT32_DONE_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12)\n%NIFGEN_INT32_FILTER_TYPE_VAL_OSP_FLAT\x10\x00\x12\x32\n.NIFGEN_INT32_FILTER_TYPE_VAL_OSP_RAISED_COSINE\x10\x01\x12\x37\n3NIFGEN_INT32_FILTER_TYPE_VAL_OSP_ROOT_RAISED_COSINE\x10\x02\x12-\n)NIFGEN_INT32_FILTER_TYPE_VAL_OSP_GAUSSIAN\x10\x03\x12+\n\'NIFGEN_INT32_FILTER_TYPE_VAL_OSP_CUSTOM\x10\x04\x12\x43\n=NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_FIRST_FREQ_LIST_HANDLE\x10\xc0\x9a\x0c\x12\x42\n<NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_LAST_FREQ_LIST_HANDLE\x10\xcf\xe8\x0c\x12@\n3NIFGEN_INT32_FREQUENCY_LIST_HANDLE_VAL_NO_FREQ_LIST\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n.NIFGEN_INT32_IDLE_BEHAVIOR_VAL_HOLD_LAST_VALUE\x10\x90\x03\x12\x31\n,NIFGEN_INT32_IDLE_BEHAVIOR_VAL_JUMP_TO_VALUE\x10\x91\x03\x12\x42\n>NIFGEN_INT32_MARKER_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x35\n1NIFGEN_INT32_MARKER_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x37\n3NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x37\n3NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12\x38\n4NIFGEN_INT32_MARKER_EVENT_OUTPUT_BEHAVIOR_VAL_TOGGLE\x10g\x12<\n8NIFGEN_INT32_MARKER_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12;\n7NIFGEN_INT32_MARKER_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12H\nDNIFGEN_INT32_MARKER_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12;\n7NIFGEN_INT32_MARKER_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12;\n7NIFGEN_INT32_MARKER_EVENT_TOGGLE_INITIAL_STATE_VAL_HIGH\x10\x65\x12:\n6NIFGEN_INT32_MARKER_EVENT_TOGGLE_INITIAL_STATE_VAL_LOW\x10\x66\x12$\n NIFGEN_INT32_OSP_MODE_VAL_OSP_IF\x10\x00\x12*\n&NIFGEN_INT32_OSP_MODE_VAL_OSP_BASEBAND\x10\x01\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_ERROR_REPORTING_VAL_ERROR_REPORTING_ERROR\x10\x00\x12J\nFNIFGEN_INT32_OSP_OVERFLOW_ERROR_REPORTING_VAL_ERROR_REPORTING_DISABLED\x10\x02\x12:\n6NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_NONE\x10\x00\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_GAIN_I\x10\x01\x12G\nCNIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_GAIN_Q\x10\x02\x12I\nENIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_OFFSET_I\x10\x04\x12I\nENIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PRE_FILTER_OFFSET_Q\x10\x08\x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_FIR_FILTER_I\x10\x10\x12\x43\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PFIR_FILTER_I\x10\x10\x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_FIR_FILTER_Q\x10 \x12\x43\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_PFIR_FILTER_Q\x10 \x12\x42\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CIC_FILTER_I\x10@\x12\x43\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CIC_FILTER_Q\x10\x80\x01\x12\x43\n>NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_COMPLEX_DATA\x10\x80\x02\x12\x44\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CFIR_FILTER_I\x10\x80\x04\x12\x44\n?NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_CFIR_FILTER_Q\x10\x80\x08\x12@\n;NIFGEN_INT32_OSP_OVERFLOW_STATUS_VAL_OSP_OVERFLOW_EQUALIZER\x10\x80\x10\x12,\n(NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_FUNC\x10\x00\x12+\n\'NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_ARB\x10\x01\x12+\n\'NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_SEQ\x10\x02\x12\x31\n-NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_FREQ_LIST\x10\x65\x12.\n*NIFGEN_INT32_OUTPUT_MODE_VAL_OUTPUT_SCRIPT\x10\x66\x12\x43\n?NIFGEN_INT32_READY_FOR_START_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12\x42\n>NIFGEN_INT32_READY_FOR_START_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x41\n=NIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_EDGE_EDGE_VAL_RISING_EDGE\x10\x65\x12\x42\n>NIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_EDGE_EDGE_VAL_FALLING_EDGE\x10\x66\x12J\nFNIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_LEVEL_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12I\nENIFGEN_INT32_SCRIPT_TRIGGER_DIGITAL_LEVEL_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x32\n.NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_TRIG_NONE\x10\x65\x12\x35\n1NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\x66\x12\x36\n2NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_DIGITAL_LEVEL\x10g\x12\x36\n2NIFGEN_INT32_SCRIPT_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10h\x12@\n<NIFGEN_INT32_START_TRIGGER_DIGITAL_EDGE_EDGE_VAL_RISING_EDGE\x10\x65\x12\x41\n=NIFGEN_INT32_START_TRIGGER_DIGITAL_EDGE_EDGE_VAL_FALLING_EDGE\x10\x66\x12\x31\n-NIFGEN_INT32_START_TRIGGER_TYPE_VAL_TRIG_NONE\x10\x65\x12\x34\n0NIFGEN_INT32_START_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\x66\x12\x35\n1NIFGEN_INT32_START_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10h\x12=\n9NIFGEN_INT32_START_TRIGGER_TYPE_VAL_P2P_ENDPOINT_FULLNESS\x10j\x12;\n7NIFGEN_INT32_STARTED_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_HIGH\x10\x65\x12:\n6NIFGEN_INT32_STARTED_EVENT_ACTIVE_LEVEL_VAL_ACTIVE_LOW\x10\x66\x12\x43\n?NIFGEN_INT32_STARTED_EVENT_DELAY_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12\x36\n2NIFGEN_INT32_STARTED_EVENT_DELAY_UNITS_VAL_SECONDS\x10\x66\x12\x38\n4NIFGEN_INT32_STARTED_EVENT_OUTPUT_BEHAVIOR_VAL_PULSE\x10\x65\x12\x38\n4NIFGEN_INT32_STARTED_EVENT_OUTPUT_BEHAVIOR_VAL_LEVEL\x10\x66\x12=\n9NIFGEN_INT32_STARTED_EVENT_PULSE_POLARITY_VAL_ACTIVE_HIGH\x10\x65\x12<\n8NIFGEN_INT32_STARTED_EVENT_PULSE_POLARITY_VAL_ACTIVE_LOW\x10\x66\x12I\nENIFGEN_INT32_STARTED_EVENT_PULSE_WIDTH_UNITS_VAL_SAMPLE_CLOCK_PERIODS\x10\x65\x12<\n8NIFGEN_INT32_STARTED_EVENT_PULSE_WIDTH_UNITS_VAL_SECONDS\x10\x66\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL0\x10o\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL1\x10p\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL2\x10q\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL3\x10r\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL4\x10s\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL5\x10t\x12\x30\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_TTL6\x10u\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_3\x10\x90\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_4\x10\x91\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_5\x10\x92\x01\x12\x33\n.NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_RTSI_6\x10\x93\x01\x12\x31\n,NIFGEN_INT32_SYNCHRONIZATION_SOURCE_VAL_NONE\x10\xe8\x07\x12\x39\n4NIFGEN_INT32_TERMINAL_CONFIGURATION_VAL_SINGLE_ENDED\x10\xac\x02\x12\x39\n4NIFGEN_INT32_TERMINAL_CONFIGURATION_VAL_DIFFERENTIAL\x10\xad\x02\x12(\n$NIFGEN_INT32_TRIGGER_MODE_VAL_SINGLE\x10\x01\x12,\n(NIFGEN_INT32_TRIGGER_MODE_VAL_CONTINUOUS\x10\x02\x12)\n%NIFGEN_INT32_TRIGGER_MODE_VAL_STEPPED\x10\x03\x12\'\n#NIFGEN_INT32_TRIGGER_MODE_VAL_BURST\x10\x04\x12-\n)NIFGEN_INT32_TRIGGER_SOURCE_VAL_IMMEDIATE\x10\x00\x12,\n(NIFGEN_INT32_TRIGGER_SOURCE_VAL_EXTERNAL\x10\x01\x12\x31\n-NIFGEN_INT32_TRIGGER_SOURCE_VAL_SOFTWARE_TRIG\x10\x02\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL0\x10o\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL1\x10p\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL2\x10q\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL3\x10r\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL4\x10s\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL5\x10t\x12(\n$NIFGEN_INT32_TRIGGER_SOURCE_VAL_TTL6\x10u\x12-\n(NIFGEN_INT32_TRIGGER_SOURCE_VAL_PXI_STAR\x10\x83\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_3\x10\x90\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_4\x10\x91\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_5\x10\x92\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_6\x10\x93\x01\x12+\n&NIFGEN_INT32_TRIGGER_SOURCE_VAL_RTSI_7\x10\xf2\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_0\x10\xf3\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_1\x10\xf4\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_2\x10\xf5\x07\x12*\n%NIFGEN_INT32_TRIGGER_SOURCE_VAL_PFI_3\x10\xf6\x07\x12\x33\n.NIFGEN_INT32_TRIGGER_SOURCE_VAL_OTHER_TERMINAL\x10\xfa\x07\x12\x31\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_INTERNAL\x10\x00\x12\x31\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_EXTERNAL\x10\x01\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL1\x10p\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL2\x10q\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL3\x10r\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL4\x10s\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL5\x10t\x12-\n)NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_TTL6\x10u\x12\x32\n-NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_PXI_STAR\x10\x83\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_0\x10\x8d\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_1\x10\x8e\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_2\x10\x8f\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_3\x10\x90\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_4\x10\x91\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_5\x10\x92\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_6\x10\x93\x01\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_RTSI_7\x10\xf2\x07\x12\x38\n3NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_OTHER_TERMINAL\x10\xfa\x07\x12\x30\n+NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_CLK_IN\x10\xb2\t\x12\x34\n/NIFGEN_INT32_UPDATE_CLOCK_SOURCE_VAL_DDC_CLK_IN\x10\xb3\t\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_B\x10\x00\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_D\x10\x01\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_G\x10\x02\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_H\x10\x03\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_I\x10\x04\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_M\x10\x05\x12.\n*NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_PAL_N\x10\x06\x12/\n+NIFGEN_INT32_VIDEO_WAVEFORM_TYPE_VAL_NTSC_M\x10\x07\x12\x33\n.NIFGEN_INT32_WAIT_BEHAVIOR_VAL_HOLD_LAST_VALUE\x10\x90\x03\x12\x31\n,NIFGEN_INT32_WAIT_BEHAVIOR_VAL_JUMP_TO_VALUE\x10\x91\x03\x12&\n\"NIFGEN_INT32_WAVEFORM_VAL_WFM_SINE\x10\x01\x12(\n$NIFGEN_INT32_WAVEFORM_VAL_WFM_SQUARE\x10\x02\x12*\n&NIFGEN_INT32_WAVEFORM_VAL_WFM_TRIANGLE\x10\x03\x12)\n%NIFGEN_INT32_WAVEFORM_VAL_WFM_RAMP_UP\x10\x04\x12+\n\'NIFGEN_INT32_WAVEFORM_VAL_WFM_RAMP_DOWN\x10\x05\x12$\n NIFGEN_INT32_WAVEFORM_VAL_WFM_DC\x10\x06\x12\'\n#NIFGEN_INT32_WAVEFORM_VAL_WFM_NOISE\x10\x65\x12&\n\"NIFGEN_INT32_WAVEFORM_VAL_WFM_USER\x10\x66\x1a\x02\x10\x01*\xa7\x02\n\x1bNiFgenReal64AttributeValues\x12\x1d\n\x19NIFGEN_REAL64_UNSPECIFIED\x10\x00\x12\x44\n7NIFGEN_REAL64_LOAD_IMPEDANCE_VAL_MATCHED_LOAD_IMPEDANCE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n*NIFGEN_REAL64_OUTPUT_IMPEDANCE_VAL_50_OHMS\x10\x32\x12.\n*NIFGEN_REAL64_OUTPUT_IMPEDANCE_VAL_75_OHMS\x10K\x12?\n2NIFGEN_REAL64_SAMPLE_RATE_VAL_EXTERNAL_SAMPLE_RATE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x1a\x02\x10\x01*\xcf\n\n!NiFgenStringAttributeValuesMapped\x12$\n NIFGEN_STRING_MAPPED_UNSPECIFIED\x10\x00\x12I\nENIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_CLOCK_IN_COLLISION_AVOIDANCE\x10\x01\x12\x45\nANIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_NONE_COLLISION_AVOIDANCE\x10\x02\x12X\nTNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_ONBOARD_REFERENCE_CLOCK_COLLISION_AVOIDANCE\x10\x03\x12J\nFNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_PXI_CLOCK_COLLISION_AVOIDANCE\x10\x04\x12G\nCNIFGEN_STRING_REFERENCE_CLOCK_SOURCE_VAL_RTSI_7_COLLISION_AVOIDANCE\x10\x05\x12\x32\n.NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_CLOCK_IN\x10\x06\x12\x36\n2NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_DDC_CLOCK_IN\x10\x07\x12\x37\n3NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_ONBOARD_CLOCK\x10\x08\x12\x37\n3NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_STAR_LINE\x10\t\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_0_RTSI_0\x10\n\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_1_RTSI_1\x10\x0b\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_2_RTSI_2\x10\x0c\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_3_RTSI_3\x10\r\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_4_RTSI_4\x10\x0e\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_5_RTSI_5\x10\x0f\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_6_RTSI_6\x10\x10\x12\x43\n?NIFGEN_STRING_SAMPLE_CLOCK_SOURCE_VAL_PXI_TRIGGER_LINE_7_RTSI_7\x10\x11\x12;\n7NIFGEN_STRING_SAMPLE_CLOCK_TIMEBASE_SOURCE_VAL_CLOCK_IN\x10\x12\x12@\n<NIFGEN_STRING_SAMPLE_CLOCK_TIMEBASE_SOURCE_VAL_ONBOARD_CLOCK\x10\x13\x32\xdbn\n\x06NiFgen\x12;\n\x04Init\x12\x18.nifgen_grpc.InitRequest\x1a\x19.nifgen_grpc.InitResponse\x12\\\n\x0fInitWithOptions\x12#.nifgen_grpc.InitWithOptionsRequest\x1a$.nifgen_grpc.InitWithOptionsResponse\x12q\n\x16InitializeWithChannels\x12*.nifgen_grpc.InitializeWithChannelsRequest\x1a+.nifgen_grpc.InitializeWithChannelsResponse\x12>\n\x05\x43lose\x12\x19.nifgen_grpc.CloseRequest\x1a\x1a.nifgen_grpc.CloseResponse\x12>\n\x05Reset\x12\x19.nifgen_grpc.ResetRequest\x1a\x1a.nifgen_grpc.ResetResponse\x12G\n\x08SelfTest\x12\x1c.nifgen_grpc.SelfTestRequest\x1a\x1d.nifgen_grpc.SelfTestResponse\x12M\n\nErrorQuery\x12\x1e.nifgen_grpc.ErrorQueryRequest\x1a\x1f.nifgen_grpc.ErrorQueryResponse\x12S\n\x0c\x45rrorMessage\x12 .nifgen_grpc.ErrorMessageRequest\x1a!.nifgen_grpc.ErrorMessageResponse\x12V\n\rRevisionQuery\x12!.nifgen_grpc.RevisionQueryRequest\x1a\".nifgen_grpc.RevisionQueryResponse\x12G\n\x08GetError\x12\x1c.nifgen_grpc.GetErrorRequest\x1a\x1d.nifgen_grpc.GetErrorResponse\x12M\n\nClearError\x12\x1e.nifgen_grpc.ClearErrorRequest\x1a\x1f.nifgen_grpc.ClearErrorResponse\x12S\n\x0c\x45rrorHandler\x12 .nifgen_grpc.ErrorHandlerRequest\x1a!.nifgen_grpc.ErrorHandlerResponse\x12Y\n\x0eGetChannelName\x12\".nifgen_grpc.GetChannelNameRequest\x1a#.nifgen_grpc.GetChannelNameResponse\x12n\n\x15ResetInterchangeCheck\x12).nifgen_grpc.ResetInterchangeCheckRequest\x1a*.nifgen_grpc.ResetInterchangeCheckResponse\x12w\n\x18\x43learInterchangeWarnings\x12,.nifgen_grpc.ClearInterchangeWarningsRequest\x1a-.nifgen_grpc.ClearInterchangeWarningsResponse\x12t\n\x17InvalidateAllAttributes\x12+.nifgen_grpc.InvalidateAllAttributesRequest\x1a,.nifgen_grpc.InvalidateAllAttributesResponse\x12\x62\n\x11ResetWithDefaults\x12%.nifgen_grpc.ResetWithDefaultsRequest\x1a&.nifgen_grpc.ResetWithDefaultsResponse\x12\x44\n\x07\x44isable\x12\x1b.nifgen_grpc.DisableRequest\x1a\x1c.nifgen_grpc.DisableResponse\x12\x41\n\x06\x43ommit\x12\x1a.nifgen_grpc.CommitRequest\x1a\x1b.nifgen_grpc.CommitResponse\x12_\n\x10GetHardwareState\x12$.nifgen_grpc.GetHardwareStateRequest\x1a%.nifgen_grpc.GetHardwareStateResponse\x12V\n\rWaitUntilDone\x12!.nifgen_grpc.WaitUntilDoneRequest\x1a\".nifgen_grpc.WaitUntilDoneResponse\x12\x41\n\x06IsDone\x12\x1a.nifgen_grpc.IsDoneRequest\x1a\x1b.nifgen_grpc.IsDoneResponse\x12P\n\x0bResetDevice\x12\x1f.nifgen_grpc.ResetDeviceRequest\x1a .nifgen_grpc.ResetDeviceResponse\x12q\n\x16\x43onfigureOperationMode\x12*.nifgen_grpc.ConfigureOperationModeRequest\x1a+.nifgen_grpc.ConfigureOperationModeResponse\x12h\n\x13\x43onfigureOutputMode\x12\'.nifgen_grpc.ConfigureOutputModeRequest\x1a(.nifgen_grpc.ConfigureOutputModeResponse\x12t\n\x17\x43onfigureReferenceClock\x12+.nifgen_grpc.ConfigureReferenceClockRequest\x1a,.nifgen_grpc.ConfigureReferenceClockResponse\x12w\n\x18\x43onfigureOutputImpedance\x12,.nifgen_grpc.ConfigureOutputImpedanceRequest\x1a-.nifgen_grpc.ConfigureOutputImpedanceResponse\x12q\n\x16\x43onfigureOutputEnabled\x12*.nifgen_grpc.ConfigureOutputEnabledRequest\x1a+.nifgen_grpc.ConfigureOutputEnabledResponse\x12\x62\n\x11\x43onfigureChannels\x12%.nifgen_grpc.ConfigureChannelsRequest\x1a&.nifgen_grpc.ConfigureChannelsResponse\x12\x65\n\x12InitiateGeneration\x12&.nifgen_grpc.InitiateGenerationRequest\x1a\'.nifgen_grpc.InitiateGenerationResponse\x12\\\n\x0f\x41\x62ortGeneration\x12#.nifgen_grpc.AbortGenerationRequest\x1a$.nifgen_grpc.AbortGenerationResponse\x12z\n\x19\x43onfigureStandardWaveform\x12-.nifgen_grpc.ConfigureStandardWaveformRequest\x1a..nifgen_grpc.ConfigureStandardWaveformResponse\x12}\n\x1a\x44\x65\x66ineUserStandardWaveform\x12..nifgen_grpc.DefineUserStandardWaveformRequest\x1a/.nifgen_grpc.DefineUserStandardWaveformResponse\x12z\n\x19\x43learUserStandardWaveform\x12-.nifgen_grpc.ClearUserStandardWaveformRequest\x1a..nifgen_grpc.ClearUserStandardWaveformResponse\x12\x65\n\x12\x43onfigureFrequency\x12&.nifgen_grpc.ConfigureFrequencyRequest\x1a\'.nifgen_grpc.ConfigureFrequencyResponse\x12\x65\n\x12\x43onfigureAmplitude\x12&.nifgen_grpc.ConfigureAmplitudeRequest\x1a\'.nifgen_grpc.ConfigureAmplitudeResponse\x12t\n\x17QueryArbWfmCapabilities\x12+.nifgen_grpc.QueryArbWfmCapabilitiesRequest\x1a,.nifgen_grpc.QueryArbWfmCapabilitiesResponse\x12\x62\n\x11\x43reateWaveformF64\x12%.nifgen_grpc.CreateWaveformF64Request\x1a&.nifgen_grpc.CreateWaveformF64Response\x12\x62\n\x11\x43reateWaveformI16\x12%.nifgen_grpc.CreateWaveformI16Request\x1a&.nifgen_grpc.CreateWaveformI16Response\x12w\n\x18\x43reateWaveformComplexF64\x12,.nifgen_grpc.CreateWaveformComplexF64Request\x1a-.nifgen_grpc.CreateWaveformComplexF64Response\x12z\n\x19\x43reateWaveformFromFileI16\x12-.nifgen_grpc.CreateWaveformFromFileI16Request\x1a..nifgen_grpc.CreateWaveformFromFileI16Response\x12z\n\x19\x43reateWaveformFromFileF64\x12-.nifgen_grpc.CreateWaveformFromFileF64Request\x1a..nifgen_grpc.CreateWaveformFromFileF64Response\x12h\n\x13\x43onfigureSampleRate\x12\'.nifgen_grpc.ConfigureSampleRateRequest\x1a(.nifgen_grpc.ConfigureSampleRateResponse\x12k\n\x14\x43onfigureArbWaveform\x12(.nifgen_grpc.ConfigureArbWaveformRequest\x1a).nifgen_grpc.ConfigureArbWaveformResponse\x12_\n\x10\x43learArbWaveform\x12$.nifgen_grpc.ClearArbWaveformRequest\x1a%.nifgen_grpc.ClearArbWaveformResponse\x12n\n\x15\x41llocateNamedWaveform\x12).nifgen_grpc.AllocateNamedWaveformRequest\x1a*.nifgen_grpc.AllocateNamedWaveformResponse\x12\x92\x01\n!SetNamedWaveformNextWritePosition\x12\x35.nifgen_grpc.SetNamedWaveformNextWritePositionRequest\x1a\x36.nifgen_grpc.SetNamedWaveformNextWritePositionResponse\x12n\n\x15WriteNamedWaveformF64\x12).nifgen_grpc.WriteNamedWaveformF64Request\x1a*.nifgen_grpc.WriteNamedWaveformF64Response\x12n\n\x15WriteNamedWaveformI16\x12).nifgen_grpc.WriteNamedWaveformI16Request\x1a*.nifgen_grpc.WriteNamedWaveformI16Response\x12\x83\x01\n\x1cWriteNamedWaveformComplexF64\x12\x30.nifgen_grpc.WriteNamedWaveformComplexF64Request\x1a\x31.nifgen_grpc.WriteNamedWaveformComplexF64Response\x12\x83\x01\n\x1cWriteNamedWaveformComplexI16\x12\x30.nifgen_grpc.WriteNamedWaveformComplexI16Request\x1a\x31.nifgen_grpc.WriteNamedWaveformComplexI16Response\x12h\n\x13\x44\x65leteNamedWaveform\x12\'.nifgen_grpc.DeleteNamedWaveformRequest\x1a(.nifgen_grpc.DeleteNamedWaveformResponse\x12t\n\x17QueryArbSeqCapabilities\x12+.nifgen_grpc.QueryArbSeqCapabilitiesRequest\x1a,.nifgen_grpc.QueryArbSeqCapabilitiesResponse\x12\x62\n\x11\x43reateArbSequence\x12%.nifgen_grpc.CreateArbSequenceRequest\x1a&.nifgen_grpc.CreateArbSequenceResponse\x12z\n\x19\x43reateAdvancedArbSequence\x12-.nifgen_grpc.CreateAdvancedArbSequenceRequest\x1a..nifgen_grpc.CreateAdvancedArbSequenceResponse\x12k\n\x14\x43onfigureArbSequence\x12(.nifgen_grpc.ConfigureArbSequenceRequest\x1a).nifgen_grpc.ConfigureArbSequenceResponse\x12_\n\x10\x43learArbSequence\x12$.nifgen_grpc.ClearArbSequenceRequest\x1a%.nifgen_grpc.ClearArbSequenceResponse\x12Y\n\x0e\x43learArbMemory\x12\".nifgen_grpc.ClearArbMemoryRequest\x1a#.nifgen_grpc.ClearArbMemoryResponse\x12z\n\x19QueryFreqListCapabilities\x12-.nifgen_grpc.QueryFreqListCapabilitiesRequest\x1a..nifgen_grpc.QueryFreqListCapabilitiesResponse\x12Y\n\x0e\x43reateFreqList\x12\".nifgen_grpc.CreateFreqListRequest\x1a#.nifgen_grpc.CreateFreqListResponse\x12\x62\n\x11\x43onfigureFreqList\x12%.nifgen_grpc.ConfigureFreqListRequest\x1a&.nifgen_grpc.ConfigureFreqListResponse\x12V\n\rClearFreqList\x12!.nifgen_grpc.ClearFreqListRequest\x1a\".nifgen_grpc.ClearFreqListResponse\x12P\n\x0bWriteScript\x12\x1f.nifgen_grpc.WriteScriptRequest\x1a .nifgen_grpc.WriteScriptResponse\x12S\n\x0c\x44\x65leteScript\x12 .nifgen_grpc.DeleteScriptRequest\x1a!.nifgen_grpc.DeleteScriptResponse\x12S\n\x0c\x45xportSignal\x12 .nifgen_grpc.ExportSignalRequest\x1a!.nifgen_grpc.ExportSignalResponse\x12Y\n\x0eRouteSignalOut\x12\".nifgen_grpc.RouteSignalOutRequest\x1a#.nifgen_grpc.RouteSignalOutResponse\x12t\n\x17SendSoftwareEdgeTrigger\x12+.nifgen_grpc.SendSoftwareEdgeTriggerRequest\x1a,.nifgen_grpc.SendSoftwareEdgeTriggerResponse\x12\x8f\x01\n ConfigureDigitalEdgeStartTrigger\x12\x34.nifgen_grpc.ConfigureDigitalEdgeStartTriggerRequest\x1a\x35.nifgen_grpc.ConfigureDigitalEdgeStartTriggerResponse\x12\x92\x01\n!ConfigureSoftwareEdgeStartTrigger\x12\x35.nifgen_grpc.ConfigureSoftwareEdgeStartTriggerRequest\x1a\x36.nifgen_grpc.ConfigureSoftwareEdgeStartTriggerResponse\x12h\n\x13\x44isableStartTrigger\x12\'.nifgen_grpc.DisableStartTriggerRequest\x1a(.nifgen_grpc.DisableStartTriggerResponse\x12\xa7\x01\n(ConfigureP2PEndpointFullnessStartTrigger\x12<.nifgen_grpc.ConfigureP2PEndpointFullnessStartTriggerRequest\x1a=.nifgen_grpc.ConfigureP2PEndpointFullnessStartTriggerResponse\x12\x92\x01\n!ConfigureDigitalEdgeScriptTrigger\x12\x35.nifgen_grpc.ConfigureDigitalEdgeScriptTriggerRequest\x1a\x36.nifgen_grpc.ConfigureDigitalEdgeScriptTriggerResponse\x12\x95\x01\n\"ConfigureDigitalLevelScriptTrigger\x12\x36.nifgen_grpc.ConfigureDigitalLevelScriptTriggerRequest\x1a\x37.nifgen_grpc.ConfigureDigitalLevelScriptTriggerResponse\x12\x95\x01\n\"ConfigureSoftwareEdgeScriptTrigger\x12\x36.nifgen_grpc.ConfigureSoftwareEdgeScriptTriggerRequest\x1a\x37.nifgen_grpc.ConfigureSoftwareEdgeScriptTriggerResponse\x12k\n\x14\x44isableScriptTrigger\x12(.nifgen_grpc.DisableScriptTriggerRequest\x1a).nifgen_grpc.DisableScriptTriggerResponse\x12\x65\n\x12\x43onfigureClockMode\x12&.nifgen_grpc.ConfigureClockModeRequest\x1a\'.nifgen_grpc.ConfigureClockModeResponse\x12\x89\x01\n\x1e\x41\x64justSampleClockRelativeDelay\x12\x32.nifgen_grpc.AdjustSampleClockRelativeDelayRequest\x1a\x33.nifgen_grpc.AdjustSampleClockRelativeDelayResponse\x12_\n\x10\x41llocateWaveform\x12$.nifgen_grpc.AllocateWaveformRequest\x1a%.nifgen_grpc.AllocateWaveformResponse\x12\x83\x01\n\x1cSetWaveformNextWritePosition\x12\x30.nifgen_grpc.SetWaveformNextWritePositionRequest\x1a\x31.nifgen_grpc.SetWaveformNextWritePositionResponse\x12V\n\rWriteWaveform\x12!.nifgen_grpc.WriteWaveformRequest\x1a\".nifgen_grpc.WriteWaveformResponse\x12n\n\x15WriteBinary16Waveform\x12).nifgen_grpc.WriteBinary16WaveformRequest\x1a*.nifgen_grpc.WriteBinary16WaveformResponse\x12t\n\x17WriteWaveformComplexF64\x12+.nifgen_grpc.WriteWaveformComplexF64Request\x1a,.nifgen_grpc.WriteWaveformComplexF64Response\x12\x83\x01\n\x1cWriteComplexBinary16Waveform\x12\x30.nifgen_grpc.WriteComplexBinary16WaveformRequest\x1a\x31.nifgen_grpc.WriteComplexBinary16WaveformResponse\x12\x44\n\x07SelfCal\x12\x1b.nifgen_grpc.SelfCalRequest\x1a\x1c.nifgen_grpc.SelfCalResponse\x12h\n\x13GetSelfCalSupported\x12\'.nifgen_grpc.GetSelfCalSupportedRequest\x1a(.nifgen_grpc.GetSelfCalSupportedResponse\x12z\n\x19GetSelfCalLastDateAndTime\x12-.nifgen_grpc.GetSelfCalLastDateAndTimeRequest\x1a..nifgen_grpc.GetSelfCalLastDateAndTimeResponse\x12w\n\x18GetExtCalLastDateAndTime\x12,.nifgen_grpc.GetExtCalLastDateAndTimeRequest\x1a-.nifgen_grpc.GetExtCalLastDateAndTimeResponse\x12\x65\n\x12GetSelfCalLastTemp\x12&.nifgen_grpc.GetSelfCalLastTempRequest\x1a\'.nifgen_grpc.GetSelfCalLastTempResponse\x12\x62\n\x11GetExtCalLastTemp\x12%.nifgen_grpc.GetExtCalLastTempRequest\x1a&.nifgen_grpc.GetExtCalLastTempResponse\x12\x83\x01\n\x1cGetExtCalRecommendedInterval\x12\x30.nifgen_grpc.GetExtCalRecommendedIntervalRequest\x1a\x31.nifgen_grpc.GetExtCalRecommendedIntervalResponse\x12q\n\x16ReadCurrentTemperature\x12*.nifgen_grpc.ReadCurrentTemperatureRequest\x1a+.nifgen_grpc.ReadCurrentTemperatureResponse\x12\x9b\x01\n$ConfigureCustomFIRFilterCoefficients\x12\x38.nifgen_grpc.ConfigureCustomFIRFilterCoefficientsRequest\x1a\x39.nifgen_grpc.ConfigureCustomFIRFilterCoefficientsResponse\x12w\n\x18GetFIRFilterCoefficients\x12,.nifgen_grpc.GetFIRFilterCoefficientsRequest\x1a-.nifgen_grpc.GetFIRFilterCoefficientsResponse\x12t\n\x17GetStreamEndpointHandle\x12+.nifgen_grpc.GetStreamEndpointHandleRequest\x1a,.nifgen_grpc.GetStreamEndpointHandleResponse\x12h\n\x13WriteP2PEndpointI16\x12\'.nifgen_grpc.WriteP2PEndpointI16Request\x1a(.nifgen_grpc.WriteP2PEndpointI16Response\x12w\n\x18\x43onfigureSynchronization\x12,.nifgen_grpc.ConfigureSynchronizationRequest\x1a-.nifgen_grpc.ConfigureSynchronizationResponse\x12t\n\x17\x45nableDigitalPatterning\x12+.nifgen_grpc.EnableDigitalPatterningRequest\x1a,.nifgen_grpc.EnableDigitalPatterningResponse\x12w\n\x18\x44isableDigitalPatterning\x12,.nifgen_grpc.DisableDigitalPatterningRequest\x1a-.nifgen_grpc.DisableDigitalPatterningResponse\x12h\n\x13\x45nableDigitalFilter\x12\'.nifgen_grpc.EnableDigitalFilterRequest\x1a(.nifgen_grpc.EnableDigitalFilterResponse\x12k\n\x14\x44isableDigitalFilter\x12(.nifgen_grpc.DisableDigitalFilterRequest\x1a).nifgen_grpc.DisableDigitalFilterResponse\x12\x65\n\x12\x45nableAnalogFilter\x12&.nifgen_grpc.EnableAnalogFilterRequest\x1a\'.nifgen_grpc.EnableAnalogFilterResponse\x12h\n\x13\x44isableAnalogFilter\x12\'.nifgen_grpc.DisableAnalogFilterRequest\x1a(.nifgen_grpc.DisableAnalogFilterResponse\x12}\n\x1a\x43onfigureSampleClockSource\x12..nifgen_grpc.ConfigureSampleClockSourceRequest\x1a/.nifgen_grpc.ConfigureSampleClockSourceResponse\x12k\n\x14\x43onfigureTriggerMode\x12(.nifgen_grpc.ConfigureTriggerModeRequest\x1a).nifgen_grpc.ConfigureTriggerModeResponse\x12\x8f\x01\n ImportAttributeConfigurationFile\x12\x34.nifgen_grpc.ImportAttributeConfigurationFileRequest\x1a\x35.nifgen_grpc.ImportAttributeConfigurationFileResponse\x12\x8f\x01\n ExportAttributeConfigurationFile\x12\x34.nifgen_grpc.ExportAttributeConfigurationFileRequest\x1a\x35.nifgen_grpc.ExportAttributeConfigurationFileResponse\x12\x95\x01\n\"ImportAttributeConfigurationBuffer\x12\x36.nifgen_grpc.ImportAttributeConfigurationBufferRequest\x1a\x37.nifgen_grpc.ImportAttributeConfigurationBufferResponse\x12\x95\x01\n\"ExportAttributeConfigurationBuffer\x12\x36.nifgen_grpc.ExportAttributeConfigurationBufferRequest\x1a\x37.nifgen_grpc.ExportAttributeConfigurationBufferResponse\x12h\n\x13SetAttributeViInt64\x12\'.nifgen_grpc.SetAttributeViInt64Request\x1a(.nifgen_grpc.SetAttributeViInt64Response\x12n\n\x15\x43heckAttributeViInt64\x12).nifgen_grpc.CheckAttributeViInt64Request\x1a*.nifgen_grpc.CheckAttributeViInt64Response\x12h\n\x13GetAttributeViInt64\x12\'.nifgen_grpc.GetAttributeViInt64Request\x1a(.nifgen_grpc.GetAttributeViInt64Response\x12h\n\x13SetAttributeViInt32\x12\'.nifgen_grpc.SetAttributeViInt32Request\x1a(.nifgen_grpc.SetAttributeViInt32Response\x12k\n\x14SetAttributeViReal64\x12(.nifgen_grpc.SetAttributeViReal64Request\x1a).nifgen_grpc.SetAttributeViReal64Response\x12k\n\x14SetAttributeViString\x12(.nifgen_grpc.SetAttributeViStringRequest\x1a).nifgen_grpc.SetAttributeViStringResponse\x12n\n\x15SetAttributeViBoolean\x12).nifgen_grpc.SetAttributeViBooleanRequest\x1a*.nifgen_grpc.SetAttributeViBooleanResponse\x12n\n\x15SetAttributeViSession\x12).nifgen_grpc.SetAttributeViSessionRequest\x1a*.nifgen_grpc.SetAttributeViSessionResponse\x12n\n\x15\x43heckAttributeViInt32\x12).nifgen_grpc.CheckAttributeViInt32Request\x1a*.nifgen_grpc.CheckAttributeViInt32Response\x12q\n\x16\x43heckAttributeViReal64\x12*.nifgen_grpc.CheckAttributeViReal64Request\x1a+.nifgen_grpc.CheckAttributeViReal64Response\x12q\n\x16\x43heckAttributeViString\x12*.nifgen_grpc.CheckAttributeViStringRequest\x1a+.nifgen_grpc.CheckAttributeViStringResponse\x12t\n\x17\x43heckAttributeViBoolean\x12+.nifgen_grpc.CheckAttributeViBooleanRequest\x1a,.nifgen_grpc.CheckAttributeViBooleanResponse\x12t\n\x17\x43heckAttributeViSession\x12+.nifgen_grpc.CheckAttributeViSessionRequest\x1a,.nifgen_grpc.CheckAttributeViSessionResponse\x12h\n\x13GetAttributeViInt32\x12\'.nifgen_grpc.GetAttributeViInt32Request\x1a(.nifgen_grpc.GetAttributeViInt32Response\x12k\n\x14GetAttributeViReal64\x12(.nifgen_grpc.GetAttributeViReal64Request\x1a).nifgen_grpc.GetAttributeViReal64Response\x12k\n\x14GetAttributeViString\x12(.nifgen_grpc.GetAttributeViStringRequest\x1a).nifgen_grpc.GetAttributeViStringResponse\x12n\n\x15GetAttributeViBoolean\x12).nifgen_grpc.GetAttributeViBooleanRequest\x1a*.nifgen_grpc.GetAttributeViBooleanResponse\x12n\n\x15GetAttributeViSession\x12).nifgen_grpc.GetAttributeViSessionRequest\x1a*.nifgen_grpc.GetAttributeViSessionResponse\x12Y\n\x0eResetAttribute\x12\".nifgen_grpc.ResetAttributeRequest\x1a#.nifgen_grpc.ResetAttributeResponse\x12n\n\x15ManualEnableP2PStream\x12).nifgen_grpc.ManualEnableP2PStreamRequest\x1a*.nifgen_grpc.ManualEnableP2PStreamResponse\x12z\n\x19\x43reateWaveformFromFileHWS\x12-.nifgen_grpc.CreateWaveformFromFileHWSRequest\x1a..nifgen_grpc.CreateWaveformFromFileHWSResponseB<\n\x10\x63om.ni.grpc.fgenB\x06NiFgenP\x01\xaa\x02\x1dNationalInstruments.Grpc.Fgenb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nifgen_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.ni.grpc.fgenB\006NiFgenP\001\252\002\035NationalInstruments.Grpc.Fgen'
  _NIFGENINT32ATTRIBUTEVALUES._options = None
  _NIFGENINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _NIFGENREAL64ATTRIBUTEVALUES._options = None
  _NIFGENREAL64ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITRESPONSE.fields_by_name['error_message']._options = None
  _INITRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._options = None
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _globals['_NIFGENATTRIBUTE']._serialized_start=24660
  _globals['_NIFGENATTRIBUTE']._serialized_end=35325
  _globals['_OUTPUTMODE']._serialized_start=35328
  _globals['_OUTPUTMODE']._serialized_end=35545
  _globals['_WAVEFORM']._serialized_start=35548
  _globals['_WAVEFORM']._serialized_end=35869
  _globals['_SIGNAL']._serialized_start=35872
  _globals['_SIGNAL']._serialized_end=36416
  _globals['_TRIGGERMODE']._serialized_start=36419
  _globals['_TRIGGERMODE']._serialized_end=36610
  _globals['_CLOCKMODE']._serialized_start=36613
  _globals['_CLOCKMODE']._serialized_end=36743
  _globals['_RELATIVETO']._serialized_start=36745
  _globals['_RELATIVETO']._serialized_end=36863
  _globals['_HARDWARESTATE']._serialized_start=36866
  _globals['_HARDWARESTATE']._serialized_end=37098
  _globals['_BYTEORDER']._serialized_start=37100
  _globals['_BYTEORDER']._serialized_end=37190
  _globals['_TRIGGERWHEN']._serialized_start=37192
  _globals['_TRIGGERWHEN']._serialized_end=37316
  _globals['_TRIGGER']._serialized_start=37318
  _globals['_TRIGGER']._serialized_end=37430
  _globals['_FREQUENCYLISTOPTIONS']._serialized_start=37432
  _globals['_FREQUENCYLISTOPTIONS']._serialized_end=37553
  _globals['_ROUTESIGNALFROM']._serialized_start=37556
  _globals['_ROUTESIGNALFROM']._serialized_end=38461
  _globals['_ROUTESIGNALTO']._serialized_start=38464
  _globals['_ROUTESIGNALTO']._serialized_end=38993
  _globals['_SEQUENCEHANDLE']._serialized_start=38995
  _globals['_SEQUENCEHANDLE']._serialized_end=39099
  _globals['_WAVEFORMHANDLE']._serialized_start=39101
  _globals['_WAVEFORMHANDLE']._serialized_end=39205
  _globals['_NIFGENINT32ATTRIBUTEVALUES']._serialized_start=39208
  _globals['_NIFGENINT32ATTRIBUTEVALUES']._serialized_end=49641
  _globals['_NIFGENREAL64ATTRIBUTEVALUES']._serialized_start=49644
  _globals['_NIFGENREAL64ATTRIBUTEVALUES']._serialized_end=49939
  _globals['_NIFGENSTRINGATTRIBUTEVALUESMAPPED']._serialized_start=49942
  _globals['_NIFGENSTRINGATTRIBUTEVALUESMAPPED']._serialized_end=51301
  _globals['_INITREQUEST']._serialized_start=61
  _globals['_INITREQUEST']._serialized_end=238
  _globals['_INITRESPONSE']._serialized_start=240
  _globals['_INITRESPONSE']._serialized_end=366
  _globals['_INITWITHOPTIONSREQUEST']._serialized_start=369
  _globals['_INITWITHOPTIONSREQUEST']._serialized_end=580
  _globals['_INITWITHOPTIONSRESPONSE']._serialized_start=583
  _globals['_INITWITHOPTIONSRESPONSE']._serialized_end=720
  _globals['_INITIALIZEWITHCHANNELSREQUEST']._serialized_start=723
  _globals['_INITIALIZEWITHCHANNELSREQUEST']._serialized_end=945
  _globals['_INITIALIZEWITHCHANNELSRESPONSE']._serialized_start=948
  _globals['_INITIALIZEWITHCHANNELSRESPONSE']._serialized_end=1092
  _globals['_CLOSEREQUEST']._serialized_start=1094
  _globals['_CLOSEREQUEST']._serialized_end=1144
  _globals['_CLOSERESPONSE']._serialized_start=1146
  _globals['_CLOSERESPONSE']._serialized_end=1177
  _globals['_RESETREQUEST']._serialized_start=1179
  _globals['_RESETREQUEST']._serialized_end=1229
  _globals['_RESETRESPONSE']._serialized_start=1231
  _globals['_RESETRESPONSE']._serialized_end=1262
  _globals['_SELFTESTREQUEST']._serialized_start=1264
  _globals['_SELFTESTREQUEST']._serialized_end=1317
  _globals['_SELFTESTRESPONSE']._serialized_start=1319
  _globals['_SELFTESTRESPONSE']._serialized_end=1406
  _globals['_ERRORQUERYREQUEST']._serialized_start=1408
  _globals['_ERRORQUERYREQUEST']._serialized_end=1463
  _globals['_ERRORQUERYRESPONSE']._serialized_start=1465
  _globals['_ERRORQUERYRESPONSE']._serialized_end=1544
  _globals['_ERRORMESSAGEREQUEST']._serialized_start=1546
  _globals['_ERRORMESSAGEREQUEST']._serialized_end=1623
  _globals['_ERRORMESSAGERESPONSE']._serialized_start=1625
  _globals['_ERRORMESSAGERESPONSE']._serialized_end=1686
  _globals['_REVISIONQUERYREQUEST']._serialized_start=1688
  _globals['_REVISIONQUERYREQUEST']._serialized_end=1746
  _globals['_REVISIONQUERYRESPONSE']._serialized_start=1748
  _globals['_REVISIONQUERYRESPONSE']._serialized_end=1850
  _globals['_GETERRORREQUEST']._serialized_start=1852
  _globals['_GETERRORREQUEST']._serialized_end=1905
  _globals['_GETERRORRESPONSE']._serialized_start=1907
  _globals['_GETERRORRESPONSE']._serialized_end=1988
  _globals['_CLEARERRORREQUEST']._serialized_start=1990
  _globals['_CLEARERRORREQUEST']._serialized_end=2045
  _globals['_CLEARERRORRESPONSE']._serialized_start=2047
  _globals['_CLEARERRORRESPONSE']._serialized_end=2083
  _globals['_ERRORHANDLERREQUEST']._serialized_start=2085
  _globals['_ERRORHANDLERREQUEST']._serialized_end=2162
  _globals['_ERRORHANDLERRESPONSE']._serialized_start=2164
  _globals['_ERRORHANDLERRESPONSE']._serialized_end=2225
  _globals['_GETCHANNELNAMEREQUEST']._serialized_start=2227
  _globals['_GETCHANNELNAMEREQUEST']._serialized_end=2301
  _globals['_GETCHANNELNAMERESPONSE']._serialized_start=2303
  _globals['_GETCHANNELNAMERESPONSE']._serialized_end=2367
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_start=2369
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_end=2435
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_start=2437
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_end=2484
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_start=2486
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_end=2555
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_start=2557
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_end=2607
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_start=2609
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_end=2677
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_start=2679
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_end=2728
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_start=2730
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_end=2792
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_start=2794
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_end=2837
  _globals['_DISABLEREQUEST']._serialized_start=2839
  _globals['_DISABLEREQUEST']._serialized_end=2891
  _globals['_DISABLERESPONSE']._serialized_start=2893
  _globals['_DISABLERESPONSE']._serialized_end=2926
  _globals['_COMMITREQUEST']._serialized_start=2928
  _globals['_COMMITREQUEST']._serialized_end=2979
  _globals['_COMMITRESPONSE']._serialized_start=2981
  _globals['_COMMITRESPONSE']._serialized_end=3013
  _globals['_GETHARDWARESTATEREQUEST']._serialized_start=3015
  _globals['_GETHARDWARESTATEREQUEST']._serialized_end=3076
  _globals['_GETHARDWARESTATERESPONSE']._serialized_start=3078
  _globals['_GETHARDWARESTATERESPONSE']._serialized_end=3182
  _globals['_WAITUNTILDONEREQUEST']._serialized_start=3184
  _globals['_WAITUNTILDONEREQUEST']._serialized_end=3260
  _globals['_WAITUNTILDONERESPONSE']._serialized_start=3262
  _globals['_WAITUNTILDONERESPONSE']._serialized_end=3301
  _globals['_ISDONEREQUEST']._serialized_start=3303
  _globals['_ISDONEREQUEST']._serialized_end=3354
  _globals['_ISDONERESPONSE']._serialized_start=3356
  _globals['_ISDONERESPONSE']._serialized_end=3402
  _globals['_RESETDEVICEREQUEST']._serialized_start=3404
  _globals['_RESETDEVICEREQUEST']._serialized_end=3460
  _globals['_RESETDEVICERESPONSE']._serialized_start=3462
  _globals['_RESETDEVICERESPONSE']._serialized_end=3499
  _globals['_CONFIGUREOPERATIONMODEREQUEST']._serialized_start=3501
  _globals['_CONFIGUREOPERATIONMODEREQUEST']._serialized_end=3614
  _globals['_CONFIGUREOPERATIONMODERESPONSE']._serialized_start=3616
  _globals['_CONFIGUREOPERATIONMODERESPONSE']._serialized_end=3664
  _globals['_CONFIGUREOUTPUTMODEREQUEST']._serialized_start=3667
  _globals['_CONFIGUREOUTPUTMODEREQUEST']._serialized_end=3826
  _globals['_CONFIGUREOUTPUTMODERESPONSE']._serialized_start=3828
  _globals['_CONFIGUREOUTPUTMODERESPONSE']._serialized_end=3873
  _globals['_CONFIGUREREFERENCECLOCKREQUEST']._serialized_start=3876
  _globals['_CONFIGUREREFERENCECLOCKREQUEST']._serialized_end=4011
  _globals['_CONFIGUREREFERENCECLOCKRESPONSE']._serialized_start=4013
  _globals['_CONFIGUREREFERENCECLOCKRESPONSE']._serialized_end=4062
  _globals['_CONFIGUREOUTPUTIMPEDANCEREQUEST']._serialized_start=4064
  _globals['_CONFIGUREOUTPUTIMPEDANCEREQUEST']._serialized_end=4174
  _globals['_CONFIGUREOUTPUTIMPEDANCERESPONSE']._serialized_start=4176
  _globals['_CONFIGUREOUTPUTIMPEDANCERESPONSE']._serialized_end=4226
  _globals['_CONFIGUREOUTPUTENABLEDREQUEST']._serialized_start=4228
  _globals['_CONFIGUREOUTPUTENABLEDREQUEST']._serialized_end=4334
  _globals['_CONFIGUREOUTPUTENABLEDRESPONSE']._serialized_start=4336
  _globals['_CONFIGUREOUTPUTENABLEDRESPONSE']._serialized_end=4384
  _globals['_CONFIGURECHANNELSREQUEST']._serialized_start=4386
  _globals['_CONFIGURECHANNELSREQUEST']._serialized_end=4466
  _globals['_CONFIGURECHANNELSRESPONSE']._serialized_start=4468
  _globals['_CONFIGURECHANNELSRESPONSE']._serialized_end=4511
  _globals['_INITIATEGENERATIONREQUEST']._serialized_start=4513
  _globals['_INITIATEGENERATIONREQUEST']._serialized_end=4576
  _globals['_INITIATEGENERATIONRESPONSE']._serialized_start=4578
  _globals['_INITIATEGENERATIONRESPONSE']._serialized_end=4622
  _globals['_ABORTGENERATIONREQUEST']._serialized_start=4624
  _globals['_ABORTGENERATIONREQUEST']._serialized_end=4684
  _globals['_ABORTGENERATIONRESPONSE']._serialized_start=4686
  _globals['_ABORTGENERATIONRESPONSE']._serialized_end=4727
  _globals['_CONFIGURESTANDARDWAVEFORMREQUEST']._serialized_start=4730
  _globals['_CONFIGURESTANDARDWAVEFORMREQUEST']._serialized_end=4984
  _globals['_CONFIGURESTANDARDWAVEFORMRESPONSE']._serialized_start=4986
  _globals['_CONFIGURESTANDARDWAVEFORMRESPONSE']._serialized_end=5037
  _globals['_DEFINEUSERSTANDARDWAVEFORMREQUEST']._serialized_start=5039
  _globals['_DEFINEUSERSTANDARDWAVEFORMREQUEST']._serialized_end=5161
  _globals['_DEFINEUSERSTANDARDWAVEFORMRESPONSE']._serialized_start=5163
  _globals['_DEFINEUSERSTANDARDWAVEFORMRESPONSE']._serialized_end=5215
  _globals['_CLEARUSERSTANDARDWAVEFORMREQUEST']._serialized_start=5217
  _globals['_CLEARUSERSTANDARDWAVEFORMREQUEST']._serialized_end=5309
  _globals['_CLEARUSERSTANDARDWAVEFORMRESPONSE']._serialized_start=5311
  _globals['_CLEARUSERSTANDARDWAVEFORMRESPONSE']._serialized_end=5362
  _globals['_CONFIGUREFREQUENCYREQUEST']._serialized_start=5364
  _globals['_CONFIGUREFREQUENCYREQUEST']._serialized_end=5468
  _globals['_CONFIGUREFREQUENCYRESPONSE']._serialized_start=5470
  _globals['_CONFIGUREFREQUENCYRESPONSE']._serialized_end=5514
  _globals['_CONFIGUREAMPLITUDEREQUEST']._serialized_start=5516
  _globals['_CONFIGUREAMPLITUDEREQUEST']._serialized_end=5620
  _globals['_CONFIGUREAMPLITUDERESPONSE']._serialized_start=5622
  _globals['_CONFIGUREAMPLITUDERESPONSE']._serialized_end=5666
  _globals['_QUERYARBWFMCAPABILITIESREQUEST']._serialized_start=5668
  _globals['_QUERYARBWFMCAPABILITIESREQUEST']._serialized_end=5736
  _globals['_QUERYARBWFMCAPABILITIESRESPONSE']._serialized_start=5739
  _globals['_QUERYARBWFMCAPABILITIESRESPONSE']._serialized_end=5913
  _globals['_CREATEWAVEFORMF64REQUEST']._serialized_start=5915
  _globals['_CREATEWAVEFORMF64REQUEST']._serialized_end=6028
  _globals['_CREATEWAVEFORMF64RESPONSE']._serialized_start=6030
  _globals['_CREATEWAVEFORMF64RESPONSE']._serialized_end=6098
  _globals['_CREATEWAVEFORMI16REQUEST']._serialized_start=6100
  _globals['_CREATEWAVEFORMI16REQUEST']._serialized_end=6213
  _globals['_CREATEWAVEFORMI16RESPONSE']._serialized_start=6215
  _globals['_CREATEWAVEFORMI16RESPONSE']._serialized_end=6283
  _globals['_CREATEWAVEFORMCOMPLEXF64REQUEST']._serialized_start=6286
  _globals['_CREATEWAVEFORMCOMPLEXF64REQUEST']._serialized_end=6438
  _globals['_CREATEWAVEFORMCOMPLEXF64RESPONSE']._serialized_start=6440
  _globals['_CREATEWAVEFORMCOMPLEXF64RESPONSE']._serialized_end=6515
  _globals['_CREATEWAVEFORMFROMFILEI16REQUEST']._serialized_start=6518
  _globals['_CREATEWAVEFORMFROMFILEI16REQUEST']._serialized_end=6720
  _globals['_CREATEWAVEFORMFROMFILEI16RESPONSE']._serialized_start=6722
  _globals['_CREATEWAVEFORMFROMFILEI16RESPONSE']._serialized_end=6798
  _globals['_CREATEWAVEFORMFROMFILEF64REQUEST']._serialized_start=6801
  _globals['_CREATEWAVEFORMFROMFILEF64REQUEST']._serialized_end=7003
  _globals['_CREATEWAVEFORMFROMFILEF64RESPONSE']._serialized_start=7005
  _globals['_CREATEWAVEFORMFROMFILEF64RESPONSE']._serialized_end=7081
  _globals['_CONFIGURESAMPLERATEREQUEST']._serialized_start=7083
  _globals['_CONFIGURESAMPLERATEREQUEST']._serialized_end=7168
  _globals['_CONFIGURESAMPLERATERESPONSE']._serialized_start=7170
  _globals['_CONFIGURESAMPLERATERESPONSE']._serialized_end=7215
  _globals['_CONFIGUREARBWAVEFORMREQUEST']._serialized_start=7218
  _globals['_CONFIGUREARBWAVEFORMREQUEST']._serialized_end=7360
  _globals['_CONFIGUREARBWAVEFORMRESPONSE']._serialized_start=7362
  _globals['_CONFIGUREARBWAVEFORMRESPONSE']._serialized_end=7408
  _globals['_CLEARARBWAVEFORMREQUEST']._serialized_start=7411
  _globals['_CLEARARBWAVEFORMREQUEST']._serialized_end=7583
  _globals['_CLEARARBWAVEFORMRESPONSE']._serialized_start=7585
  _globals['_CLEARARBWAVEFORMRESPONSE']._serialized_end=7627
  _globals['_ALLOCATENAMEDWAVEFORMREQUEST']._serialized_start=7630
  _globals['_ALLOCATENAMEDWAVEFORMREQUEST']._serialized_end=7764
  _globals['_ALLOCATENAMEDWAVEFORMRESPONSE']._serialized_start=7766
  _globals['_ALLOCATENAMEDWAVEFORMRESPONSE']._serialized_end=7813
  _globals['_SETNAMEDWAVEFORMNEXTWRITEPOSITIONREQUEST']._serialized_start=7816
  _globals['_SETNAMEDWAVEFORMNEXTWRITEPOSITIONREQUEST']._serialized_end=8050
  _globals['_SETNAMEDWAVEFORMNEXTWRITEPOSITIONRESPONSE']._serialized_start=8052
  _globals['_SETNAMEDWAVEFORMNEXTWRITEPOSITIONRESPONSE']._serialized_end=8111
  _globals['_WRITENAMEDWAVEFORMF64REQUEST']._serialized_start=8113
  _globals['_WRITENAMEDWAVEFORMF64REQUEST']._serialized_end=8238
  _globals['_WRITENAMEDWAVEFORMF64RESPONSE']._serialized_start=8240
  _globals['_WRITENAMEDWAVEFORMF64RESPONSE']._serialized_end=8287
  _globals['_WRITENAMEDWAVEFORMI16REQUEST']._serialized_start=8289
  _globals['_WRITENAMEDWAVEFORMI16REQUEST']._serialized_end=8414
  _globals['_WRITENAMEDWAVEFORMI16RESPONSE']._serialized_start=8416
  _globals['_WRITENAMEDWAVEFORMI16RESPONSE']._serialized_end=8463
  _globals['_WRITENAMEDWAVEFORMCOMPLEXF64REQUEST']._serialized_start=8466
  _globals['_WRITENAMEDWAVEFORMCOMPLEXF64REQUEST']._serialized_end=8630
  _globals['_WRITENAMEDWAVEFORMCOMPLEXF64RESPONSE']._serialized_start=8632
  _globals['_WRITENAMEDWAVEFORMCOMPLEXF64RESPONSE']._serialized_end=8686
  _globals['_WRITENAMEDWAVEFORMCOMPLEXI16REQUEST']._serialized_start=8689
  _globals['_WRITENAMEDWAVEFORMCOMPLEXI16REQUEST']._serialized_end=8850
  _globals['_WRITENAMEDWAVEFORMCOMPLEXI16RESPONSE']._serialized_start=8852
  _globals['_WRITENAMEDWAVEFORMCOMPLEXI16RESPONSE']._serialized_end=8906
  _globals['_DELETENAMEDWAVEFORMREQUEST']._serialized_start=8908
  _globals['_DELETENAMEDWAVEFORMREQUEST']._serialized_end=9017
  _globals['_DELETENAMEDWAVEFORMRESPONSE']._serialized_start=9019
  _globals['_DELETENAMEDWAVEFORMRESPONSE']._serialized_end=9064
  _globals['_QUERYARBSEQCAPABILITIESREQUEST']._serialized_start=9066
  _globals['_QUERYARBSEQCAPABILITIESREQUEST']._serialized_end=9134
  _globals['_QUERYARBSEQCAPABILITIESRESPONSE']._serialized_start=9137
  _globals['_QUERYARBSEQCAPABILITIESRESPONSE']._serialized_end=9317
  _globals['_CREATEARBSEQUENCEREQUEST']._serialized_start=9319
  _globals['_CREATEARBSEQUENCEREQUEST']._serialized_end=9440
  _globals['_CREATEARBSEQUENCERESPONSE']._serialized_start=9442
  _globals['_CREATEARBSEQUENCERESPONSE']._serialized_end=9510
  _globals['_CREATEADVANCEDARBSEQUENCEREQUEST']._serialized_start=9513
  _globals['_CREATEADVANCEDARBSEQUENCEREQUEST']._serialized_end=9702
  _globals['_CREATEADVANCEDARBSEQUENCERESPONSE']._serialized_start=9704
  _globals['_CREATEADVANCEDARBSEQUENCERESPONSE']._serialized_end=9811
  _globals['_CONFIGUREARBSEQUENCEREQUEST']._serialized_start=9814
  _globals['_CONFIGUREARBSEQUENCEREQUEST']._serialized_end=9956
  _globals['_CONFIGUREARBSEQUENCERESPONSE']._serialized_start=9958
  _globals['_CONFIGUREARBSEQUENCERESPONSE']._serialized_end=10004
  _globals['_CLEARARBSEQUENCEREQUEST']._serialized_start=10007
  _globals['_CLEARARBSEQUENCEREQUEST']._serialized_end=10179
  _globals['_CLEARARBSEQUENCERESPONSE']._serialized_start=10181
  _globals['_CLEARARBSEQUENCERESPONSE']._serialized_end=10223
  _globals['_CLEARARBMEMORYREQUEST']._serialized_start=10225
  _globals['_CLEARARBMEMORYREQUEST']._serialized_end=10284
  _globals['_CLEARARBMEMORYRESPONSE']._serialized_start=10286
  _globals['_CLEARARBMEMORYRESPONSE']._serialized_end=10326
  _globals['_QUERYFREQLISTCAPABILITIESREQUEST']._serialized_start=10328
  _globals['_QUERYFREQLISTCAPABILITIESREQUEST']._serialized_end=10398
  _globals['_QUERYFREQLISTCAPABILITIESRESPONSE']._serialized_start=10401
  _globals['_QUERYFREQLISTCAPABILITIESRESPONSE']._serialized_end=10691
  _globals['_CREATEFREQLISTREQUEST']._serialized_start=10694
  _globals['_CREATEFREQLISTREQUEST']._serialized_end=10886
  _globals['_CREATEFREQLISTRESPONSE']._serialized_start=10888
  _globals['_CREATEFREQLISTRESPONSE']._serialized_end=10959
  _globals['_CONFIGUREFREQLISTREQUEST']._serialized_start=10962
  _globals['_CONFIGUREFREQLISTREQUEST']._serialized_end=11136
  _globals['_CONFIGUREFREQLISTRESPONSE']._serialized_start=11138
  _globals['_CONFIGUREFREQLISTRESPONSE']._serialized_end=11181
  _globals['_CLEARFREQLISTREQUEST']._serialized_start=11184
  _globals['_CLEARFREQLISTREQUEST']._serialized_end=11377
  _globals['_CLEARFREQLISTRESPONSE']._serialized_start=11379
  _globals['_CLEARFREQLISTRESPONSE']._serialized_end=11418
  _globals['_WRITESCRIPTREQUEST']._serialized_start=11420
  _globals['_WRITESCRIPTREQUEST']._serialized_end=11514
  _globals['_WRITESCRIPTRESPONSE']._serialized_start=11516
  _globals['_WRITESCRIPTRESPONSE']._serialized_end=11553
  _globals['_DELETESCRIPTREQUEST']._serialized_start=11555
  _globals['_DELETESCRIPTREQUEST']._serialized_end=11655
  _globals['_DELETESCRIPTRESPONSE']._serialized_start=11657
  _globals['_DELETESCRIPTRESPONSE']._serialized_end=11695
  _globals['_EXPORTSIGNALREQUEST']._serialized_start=11698
  _globals['_EXPORTSIGNALREQUEST']._serialized_end=11883
  _globals['_EXPORTSIGNALRESPONSE']._serialized_start=11885
  _globals['_EXPORTSIGNALRESPONSE']._serialized_end=11923
  _globals['_ROUTESIGNALOUTREQUEST']._serialized_start=11926
  _globals['_ROUTESIGNALOUTREQUEST']._serialized_end=12235
  _globals['_ROUTESIGNALOUTRESPONSE']._serialized_start=12237
  _globals['_ROUTESIGNALOUTRESPONSE']._serialized_end=12277
  _globals['_SENDSOFTWAREEDGETRIGGERREQUEST']._serialized_start=12280
  _globals['_SENDSOFTWAREEDGETRIGGERREQUEST']._serialized_end=12448
  _globals['_SENDSOFTWAREEDGETRIGGERRESPONSE']._serialized_start=12450
  _globals['_SENDSOFTWAREEDGETRIGGERRESPONSE']._serialized_end=12499
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST']._serialized_start=12501
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST']._serialized_end=12608
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE']._serialized_start=12610
  _globals['_CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE']._serialized_end=12668
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST']._serialized_start=12670
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST']._serialized_end=12748
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE']._serialized_start=12750
  _globals['_CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE']._serialized_end=12809
  _globals['_DISABLESTARTTRIGGERREQUEST']._serialized_start=12811
  _globals['_DISABLESTARTTRIGGERREQUEST']._serialized_end=12875
  _globals['_DISABLESTARTTRIGGERRESPONSE']._serialized_start=12877
  _globals['_DISABLESTARTTRIGGERRESPONSE']._serialized_end=12922
  _globals['_CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERREQUEST']._serialized_start=12924
  _globals['_CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERREQUEST']._serialized_end=13046
  _globals['_CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERRESPONSE']._serialized_start=13048
  _globals['_CONFIGUREP2PENDPOINTFULLNESSSTARTTRIGGERRESPONSE']._serialized_end=13114
  _globals['_CONFIGUREDIGITALEDGESCRIPTTRIGGERREQUEST']._serialized_start=13117
  _globals['_CONFIGUREDIGITALEDGESCRIPTTRIGGERREQUEST']._serialized_end=13245
  _globals['_CONFIGUREDIGITALEDGESCRIPTTRIGGERRESPONSE']._serialized_start=13247
  _globals['_CONFIGUREDIGITALEDGESCRIPTTRIGGERRESPONSE']._serialized_end=13306
  _globals['_CONFIGUREDIGITALLEVELSCRIPTTRIGGERREQUEST']._serialized_start=13309
  _globals['_CONFIGUREDIGITALLEVELSCRIPTTRIGGERREQUEST']._serialized_end=13523
  _globals['_CONFIGUREDIGITALLEVELSCRIPTTRIGGERRESPONSE']._serialized_start=13525
  _globals['_CONFIGUREDIGITALLEVELSCRIPTTRIGGERRESPONSE']._serialized_end=13585
  _globals['_CONFIGURESOFTWAREEDGESCRIPTTRIGGERREQUEST']._serialized_start=13587
  _globals['_CONFIGURESOFTWAREEDGESCRIPTTRIGGERREQUEST']._serialized_end=13686
  _globals['_CONFIGURESOFTWAREEDGESCRIPTTRIGGERRESPONSE']._serialized_start=13688
  _globals['_CONFIGURESOFTWAREEDGESCRIPTTRIGGERRESPONSE']._serialized_end=13748
  _globals['_DISABLESCRIPTTRIGGERREQUEST']._serialized_start=13750
  _globals['_DISABLESCRIPTTRIGGERREQUEST']._serialized_end=13835
  _globals['_DISABLESCRIPTTRIGGERRESPONSE']._serialized_start=13837
  _globals['_DISABLESCRIPTTRIGGERRESPONSE']._serialized_end=13883
  _globals['_CONFIGURECLOCKMODEREQUEST']._serialized_start=13886
  _globals['_CONFIGURECLOCKMODEREQUEST']._serialized_end=14040
  _globals['_CONFIGURECLOCKMODERESPONSE']._serialized_start=14042
  _globals['_CONFIGURECLOCKMODERESPONSE']._serialized_end=14086
  _globals['_ADJUSTSAMPLECLOCKRELATIVEDELAYREQUEST']._serialized_start=14088
  _globals['_ADJUSTSAMPLECLOCKRELATIVEDELAYREQUEST']._serialized_end=14188
  _globals['_ADJUSTSAMPLECLOCKRELATIVEDELAYRESPONSE']._serialized_start=14190
  _globals['_ADJUSTSAMPLECLOCKRELATIVEDELAYRESPONSE']._serialized_end=14246
  _globals['_ALLOCATEWAVEFORMREQUEST']._serialized_start=14248
  _globals['_ALLOCATEWAVEFORMREQUEST']._serialized_end=14354
  _globals['_ALLOCATEWAVEFORMRESPONSE']._serialized_start=14356
  _globals['_ALLOCATEWAVEFORMRESPONSE']._serialized_end=14423
  _globals['_SETWAVEFORMNEXTWRITEPOSITIONREQUEST']._serialized_start=14426
  _globals['_SETWAVEFORMNEXTWRITEPOSITIONREQUEST']._serialized_end=14657
  _globals['_SETWAVEFORMNEXTWRITEPOSITIONRESPONSE']._serialized_start=14659
  _globals['_SETWAVEFORMNEXTWRITEPOSITIONRESPONSE']._serialized_end=14713
  _globals['_WRITEWAVEFORMREQUEST']._serialized_start=14715
  _globals['_WRITEWAVEFORMREQUEST']._serialized_end=14834
  _globals['_WRITEWAVEFORMRESPONSE']._serialized_start=14836
  _globals['_WRITEWAVEFORMRESPONSE']._serialized_end=14875
  _globals['_WRITEBINARY16WAVEFORMREQUEST']._serialized_start=14877
  _globals['_WRITEBINARY16WAVEFORMREQUEST']._serialized_end=15004
  _globals['_WRITEBINARY16WAVEFORMRESPONSE']._serialized_start=15006
  _globals['_WRITEBINARY16WAVEFORMRESPONSE']._serialized_end=15053
  _globals['_WRITEWAVEFORMCOMPLEXF64REQUEST']._serialized_start=15056
  _globals['_WRITEWAVEFORMCOMPLEXF64REQUEST']._serialized_end=15217
  _globals['_WRITEWAVEFORMCOMPLEXF64RESPONSE']._serialized_start=15219
  _globals['_WRITEWAVEFORMCOMPLEXF64RESPONSE']._serialized_end=15268
  _globals['_WRITECOMPLEXBINARY16WAVEFORMREQUEST']._serialized_start=15271
  _globals['_WRITECOMPLEXBINARY16WAVEFORMREQUEST']._serialized_end=15434
  _globals['_WRITECOMPLEXBINARY16WAVEFORMRESPONSE']._serialized_start=15436
  _globals['_WRITECOMPLEXBINARY16WAVEFORMRESPONSE']._serialized_end=15490
  _globals['_SELFCALREQUEST']._serialized_start=15492
  _globals['_SELFCALREQUEST']._serialized_end=15544
  _globals['_SELFCALRESPONSE']._serialized_start=15546
  _globals['_SELFCALRESPONSE']._serialized_end=15579
  _globals['_GETSELFCALSUPPORTEDREQUEST']._serialized_start=15581
  _globals['_GETSELFCALSUPPORTEDREQUEST']._serialized_end=15645
  _globals['_GETSELFCALSUPPORTEDRESPONSE']._serialized_start=15647
  _globals['_GETSELFCALSUPPORTEDRESPONSE']._serialized_end=15720
  _globals['_GETSELFCALLASTDATEANDTIMEREQUEST']._serialized_start=15722
  _globals['_GETSELFCALLASTDATEANDTIMEREQUEST']._serialized_end=15792
  _globals['_GETSELFCALLASTDATEANDTIMERESPONSE']._serialized_start=15794
  _globals['_GETSELFCALLASTDATEANDTIMERESPONSE']._serialized_end=15917
  _globals['_GETEXTCALLASTDATEANDTIMEREQUEST']._serialized_start=15919
  _globals['_GETEXTCALLASTDATEANDTIMEREQUEST']._serialized_end=15988
  _globals['_GETEXTCALLASTDATEANDTIMERESPONSE']._serialized_start=15990
  _globals['_GETEXTCALLASTDATEANDTIMERESPONSE']._serialized_end=16112
  _globals['_GETSELFCALLASTTEMPREQUEST']._serialized_start=16114
  _globals['_GETSELFCALLASTTEMPREQUEST']._serialized_end=16177
  _globals['_GETSELFCALLASTTEMPRESPONSE']._serialized_start=16179
  _globals['_GETSELFCALLASTTEMPRESPONSE']._serialized_end=16244
  _globals['_GETEXTCALLASTTEMPREQUEST']._serialized_start=16246
  _globals['_GETEXTCALLASTTEMPREQUEST']._serialized_end=16308
  _globals['_GETEXTCALLASTTEMPRESPONSE']._serialized_start=16310
  _globals['_GETEXTCALLASTTEMPRESPONSE']._serialized_end=16374
  _globals['_GETEXTCALRECOMMENDEDINTERVALREQUEST']._serialized_start=16376
  _globals['_GETEXTCALRECOMMENDEDINTERVALREQUEST']._serialized_end=16449
  _globals['_GETEXTCALRECOMMENDEDINTERVALRESPONSE']._serialized_start=16451
  _globals['_GETEXTCALRECOMMENDEDINTERVALRESPONSE']._serialized_end=16521
  _globals['_READCURRENTTEMPERATUREREQUEST']._serialized_start=16523
  _globals['_READCURRENTTEMPERATUREREQUEST']._serialized_end=16590
  _globals['_READCURRENTTEMPERATURERESPONSE']._serialized_start=16592
  _globals['_READCURRENTTEMPERATURERESPONSE']._serialized_end=16661
  _globals['_CONFIGURECUSTOMFIRFILTERCOEFFICIENTSREQUEST']._serialized_start=16664
  _globals['_CONFIGURECUSTOMFIRFILTERCOEFFICIENTSREQUEST']._serialized_end=16795
  _globals['_CONFIGURECUSTOMFIRFILTERCOEFFICIENTSRESPONSE']._serialized_start=16797
  _globals['_CONFIGURECUSTOMFIRFILTERCOEFFICIENTSRESPONSE']._serialized_end=16859
  _globals['_GETFIRFILTERCOEFFICIENTSREQUEST']._serialized_start=16861
  _globals['_GETFIRFILTERCOEFFICIENTSREQUEST']._serialized_end=16952
  _globals['_GETFIRFILTERCOEFFICIENTSRESPONSE']._serialized_start=16954
  _globals['_GETFIRFILTERCOEFFICIENTSRESPONSE']._serialized_end=17069
  _globals['_GETSTREAMENDPOINTHANDLEREQUEST']._serialized_start=17071
  _globals['_GETSTREAMENDPOINTHANDLEREQUEST']._serialized_end=17164
  _globals['_GETSTREAMENDPOINTHANDLERESPONSE']._serialized_start=17166
  _globals['_GETSTREAMENDPOINTHANDLERESPONSE']._serialized_end=17238
  _globals['_WRITEP2PENDPOINTI16REQUEST']._serialized_start=17240
  _globals['_WRITEP2PENDPOINTI16REQUEST']._serialized_end=17350
  _globals['_WRITEP2PENDPOINTI16RESPONSE']._serialized_start=17352
  _globals['_WRITEP2PENDPOINTI16RESPONSE']._serialized_end=17397
  _globals['_CONFIGURESYNCHRONIZATIONREQUEST']._serialized_start=17399
  _globals['_CONFIGURESYNCHRONIZATIONREQUEST']._serialized_end=17522
  _globals['_CONFIGURESYNCHRONIZATIONRESPONSE']._serialized_start=17524
  _globals['_CONFIGURESYNCHRONIZATIONRESPONSE']._serialized_end=17574
  _globals['_ENABLEDIGITALPATTERNINGREQUEST']._serialized_start=17576
  _globals['_ENABLEDIGITALPATTERNINGREQUEST']._serialized_end=17666
  _globals['_ENABLEDIGITALPATTERNINGRESPONSE']._serialized_start=17668
  _globals['_ENABLEDIGITALPATTERNINGRESPONSE']._serialized_end=17717
  _globals['_DISABLEDIGITALPATTERNINGREQUEST']._serialized_start=17719
  _globals['_DISABLEDIGITALPATTERNINGREQUEST']._serialized_end=17810
  _globals['_DISABLEDIGITALPATTERNINGRESPONSE']._serialized_start=17812
  _globals['_DISABLEDIGITALPATTERNINGRESPONSE']._serialized_end=17862
  _globals['_ENABLEDIGITALFILTERREQUEST']._serialized_start=17864
  _globals['_ENABLEDIGITALFILTERREQUEST']._serialized_end=17950
  _globals['_ENABLEDIGITALFILTERRESPONSE']._serialized_start=17952
  _globals['_ENABLEDIGITALFILTERRESPONSE']._serialized_end=17997
  _globals['_DISABLEDIGITALFILTERREQUEST']._serialized_start=17999
  _globals['_DISABLEDIGITALFILTERREQUEST']._serialized_end=18086
  _globals['_DISABLEDIGITALFILTERRESPONSE']._serialized_start=18088
  _globals['_DISABLEDIGITALFILTERRESPONSE']._serialized_end=18134
  _globals['_ENABLEANALOGFILTERREQUEST']._serialized_start=18136
  _globals['_ENABLEANALOGFILTERREQUEST']._serialized_end=18258
  _globals['_ENABLEANALOGFILTERRESPONSE']._serialized_start=18260
  _globals['_ENABLEANALOGFILTERRESPONSE']._serialized_end=18304
  _globals['_DISABLEANALOGFILTERREQUEST']._serialized_start=18306
  _globals['_DISABLEANALOGFILTERREQUEST']._serialized_end=18392
  _globals['_DISABLEANALOGFILTERRESPONSE']._serialized_start=18394
  _globals['_DISABLEANALOGFILTERRESPONSE']._serialized_end=18439
  _globals['_CONFIGURESAMPLECLOCKSOURCEREQUEST']._serialized_start=18441
  _globals['_CONFIGURESAMPLECLOCKSOURCEREQUEST']._serialized_end=18541
  _globals['_CONFIGURESAMPLECLOCKSOURCERESPONSE']._serialized_start=18543
  _globals['_CONFIGURESAMPLECLOCKSOURCERESPONSE']._serialized_end=18595
  _globals['_CONFIGURETRIGGERMODEREQUEST']._serialized_start=18598
  _globals['_CONFIGURETRIGGERMODEREQUEST']._serialized_end=18784
  _globals['_CONFIGURETRIGGERMODERESPONSE']._serialized_start=18786
  _globals['_CONFIGURETRIGGERMODERESPONSE']._serialized_end=18832
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_start=18834
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_end=18930
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_start=18932
  _globals['_IMPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_end=18990
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_start=18992
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILEREQUEST']._serialized_end=19088
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_start=19090
  _globals['_EXPORTATTRIBUTECONFIGURATIONFILERESPONSE']._serialized_end=19148
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_start=19150
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_end=19252
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_start=19254
  _globals['_IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_end=19314
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_start=19316
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST']._serialized_end=19395
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_start=19397
  _globals['_EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE']._serialized_end=19480
  _globals['_SETATTRIBUTEVIINT64REQUEST']._serialized_start=19483
  _globals['_SETATTRIBUTEVIINT64REQUEST']._serialized_end=19650
  _globals['_SETATTRIBUTEVIINT64RESPONSE']._serialized_start=19652
  _globals['_SETATTRIBUTEVIINT64RESPONSE']._serialized_end=19697
  _globals['_CHECKATTRIBUTEVIINT64REQUEST']._serialized_start=19700
  _globals['_CHECKATTRIBUTEVIINT64REQUEST']._serialized_end=19869
  _globals['_CHECKATTRIBUTEVIINT64RESPONSE']._serialized_start=19871
  _globals['_CHECKATTRIBUTEVIINT64RESPONSE']._serialized_end=19918
  _globals['_GETATTRIBUTEVIINT64REQUEST']._serialized_start=19921
  _globals['_GETATTRIBUTEVIINT64REQUEST']._serialized_end=20059
  _globals['_GETATTRIBUTEVIINT64RESPONSE']._serialized_start=20061
  _globals['_GETATTRIBUTEVIINT64RESPONSE']._serialized_end=20131
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_start=20134
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_end=20395
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_start=20397
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_end=20442
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_start=20445
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_end=20708
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_start=20710
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_end=20756
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_start=20759
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_end=21035
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_start=21037
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_end=21083
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=21086
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=21251
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=21253
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=21300
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_start=21303
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_end=21492
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_start=21494
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_end=21541
  _globals['_CHECKATTRIBUTEVIINT32REQUEST']._serialized_start=21544
  _globals['_CHECKATTRIBUTEVIINT32REQUEST']._serialized_end=21807
  _globals['_CHECKATTRIBUTEVIINT32RESPONSE']._serialized_start=21809
  _globals['_CHECKATTRIBUTEVIINT32RESPONSE']._serialized_end=21856
  _globals['_CHECKATTRIBUTEVIREAL64REQUEST']._serialized_start=21859
  _globals['_CHECKATTRIBUTEVIREAL64REQUEST']._serialized_end=22124
  _globals['_CHECKATTRIBUTEVIREAL64RESPONSE']._serialized_start=22126
  _globals['_CHECKATTRIBUTEVIREAL64RESPONSE']._serialized_end=22174
  _globals['_CHECKATTRIBUTEVISTRINGREQUEST']._serialized_start=22177
  _globals['_CHECKATTRIBUTEVISTRINGREQUEST']._serialized_end=22455
  _globals['_CHECKATTRIBUTEVISTRINGRESPONSE']._serialized_start=22457
  _globals['_CHECKATTRIBUTEVISTRINGRESPONSE']._serialized_end=22505
  _globals['_CHECKATTRIBUTEVIBOOLEANREQUEST']._serialized_start=22508
  _globals['_CHECKATTRIBUTEVIBOOLEANREQUEST']._serialized_end=22675
  _globals['_CHECKATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=22677
  _globals['_CHECKATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=22726
  _globals['_CHECKATTRIBUTEVISESSIONREQUEST']._serialized_start=22729
  _globals['_CHECKATTRIBUTEVISESSIONREQUEST']._serialized_end=22920
  _globals['_CHECKATTRIBUTEVISESSIONRESPONSE']._serialized_start=22922
  _globals['_CHECKATTRIBUTEVISESSIONRESPONSE']._serialized_end=22971
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_start=22974
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_end=23112
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_start=23114
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_end=23184
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_start=23187
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_end=23326
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_start=23328
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_end=23399
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_start=23402
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_end=23541
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_start=23543
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_end=23614
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=23617
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=23757
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=23759
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=23831
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_start=23834
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_end=23974
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_start=23976
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_end=24072
  _globals['_RESETATTRIBUTEREQUEST']._serialized_start=24075
  _globals['_RESETATTRIBUTEREQUEST']._serialized_end=24208
  _globals['_RESETATTRIBUTERESPONSE']._serialized_start=24210
  _globals['_RESETATTRIBUTERESPONSE']._serialized_end=24250
  _globals['_MANUALENABLEP2PSTREAMREQUEST']._serialized_start=24252
  _globals['_MANUALENABLEP2PSTREAMREQUEST']._serialized_end=24341
  _globals['_MANUALENABLEP2PSTREAMRESPONSE']._serialized_start=24343
  _globals['_MANUALENABLEP2PSTREAMRESPONSE']._serialized_end=24390
  _globals['_CREATEWAVEFORMFROMFILEHWSREQUEST']._serialized_start=24393
  _globals['_CREATEWAVEFORMFROMFILEHWSREQUEST']._serialized_end=24579
  _globals['_CREATEWAVEFORMFROMFILEHWSRESPONSE']._serialized_start=24581
  _globals['_CREATEWAVEFORMFROMFILEHWSRESPONSE']._serialized_end=24657
  _globals['_NIFGEN']._serialized_start=51304
  _globals['_NIFGEN']._serialized_end=65475
# @@protoc_insertion_point(module_scope)
